[Libreoffice-commits] .: 4 commits - sw/source
Martin Kepplinger
mkepplinger at kemper.freedesktop.org
Thu Apr 21 12:55:33 PDT 2011
sw/source/ui/inc/actctrl.hxx | 6 -
sw/source/ui/inc/app.hrc | 10 +-
sw/source/ui/inc/autoedit.hxx | 2
sw/source/ui/inc/basesh.hxx | 6 -
sw/source/ui/inc/bmpwin.hxx | 2
sw/source/ui/inc/caption.hxx | 2
sw/source/ui/inc/cfgitems.hxx | 10 +-
sw/source/ui/inc/changedb.hxx | 2
sw/source/ui/inc/colmgr.hxx | 5 -
sw/source/ui/inc/column.hxx | 2
sw/source/ui/inc/conarc.hxx | 4
sw/source/ui/inc/concustomshape.hxx | 4
sw/source/ui/inc/conform.hxx | 2
sw/source/ui/inc/conpoly.hxx | 4
sw/source/ui/inc/conrect.hxx | 4
sw/source/ui/inc/content.hxx | 33 +++----
sw/source/ui/inc/conttree.hxx | 12 +-
sw/source/ui/inc/cption.hxx | 4
sw/source/ui/inc/dbinsdlg.hxx | 2
sw/source/ui/inc/docstdlg.hxx | 2
sw/source/ui/inc/drawbase.hxx | 12 +-
sw/source/ui/inc/dselect.hxx | 6 -
sw/source/ui/inc/edtwin.hxx | 64 +++++++-------
sw/source/ui/inc/envimg.hxx | 26 ++---
sw/source/ui/inc/fldmgr.hxx | 42 ++++-----
sw/source/ui/inc/formedt.hxx | 2
sw/source/ui/inc/frmdlg.hxx | 2
sw/source/ui/inc/frmmgr.hxx | 22 ++---
sw/source/ui/inc/frmpage.hxx | 22 ++---
sw/source/ui/inc/gloshdl.hxx | 6 -
sw/source/ui/inc/gloslst.hxx | 4
sw/source/ui/inc/hyp.hxx | 14 +--
sw/source/ui/inc/initui.hxx | 2
sw/source/ui/inc/inpdlg.hxx | 2
sw/source/ui/inc/inputwin.hxx | 4
sw/source/ui/inc/insfnote.hxx | 4
sw/source/ui/inc/labimg.hxx | 42 ++++-----
sw/source/ui/inc/linenum.hxx | 4
sw/source/ui/inc/mailmergehelper.hxx | 4
sw/source/ui/inc/multmrk.hxx | 2
sw/source/ui/inc/navicfg.hxx | 2
sw/source/ui/inc/navicont.hxx | 12 +-
sw/source/ui/inc/navipi.hxx | 8 -
sw/source/ui/inc/num.hxx | 2
sw/source/ui/inc/numpara.hxx | 4
sw/source/ui/inc/optpage.hxx | 13 +-
sw/source/ui/inc/outline.hxx | 2
sw/source/ui/inc/pgfnote.hxx | 2
sw/source/ui/inc/popbox.hxx | 2
sw/source/ui/inc/prcntfld.hxx | 2
sw/source/ui/inc/pview.hxx | 19 ++--
sw/source/ui/inc/redlndlg.hxx | 12 +-
sw/source/ui/inc/regionsw.hxx | 4
sw/source/ui/inc/scroll.hxx | 14 +--
sw/source/ui/inc/srcview.hxx | 2
sw/source/ui/inc/swcont.hxx | 12 +-
sw/source/ui/inc/swdtflvr.hxx | 4
sw/source/ui/inc/swlbox.hxx | 4
sw/source/ui/inc/swuiidxmrk.hxx | 2
sw/source/ui/inc/tabledlg.hxx | 2
sw/source/ui/inc/tmpdlg.hxx | 2
sw/source/ui/inc/toxmgr.hxx | 10 +-
sw/source/ui/inc/uiitems.hxx | 2
sw/source/ui/inc/uinums.hxx | 6 -
sw/source/ui/inc/uitool.hxx | 16 +--
sw/source/ui/inc/utlui.hrc | 2
sw/source/ui/inc/view.hxx | 77 ++++++++---------
sw/source/ui/inc/workctrl.hxx | 6 -
sw/source/ui/inc/wrap.hxx | 2
sw/source/ui/inc/wrtsh.hxx | 152 ++++++++++++++++-------------------
70 files changed, 395 insertions(+), 408 deletions(-)
New commits:
commit 0c7f5548ab4984124dee4dbb35d103d732f43008
Author: Martin Kepplinger <martinkepplinger at eml.cc>
Date: Thu Apr 21 21:52:58 2011 +0200
Translate german code comments
Translate german code comments to english!
This is contributed under the terms of the MPL 1.1 / GPLv3+ / LGPLv3+ triple
license.
diff --git a/sw/source/ui/inc/srcview.hxx b/sw/source/ui/inc/srcview.hxx
index 336a9fc..8ee18ed 100644
--- a/sw/source/ui/inc/srcview.hxx
+++ b/sw/source/ui/inc/srcview.hxx
@@ -49,7 +49,7 @@ class SwSrcView: public SfxViewShell
rtl_TextEncoding eLoadEncoding;
void Init();
- // fuer Readonly-Umschaltung
+ // for read-only switching
virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint );
diff --git a/sw/source/ui/inc/swcont.hxx b/sw/source/ui/inc/swcont.hxx
index 0688dd6..58111b5 100644
--- a/sw/source/ui/inc/swcont.hxx
+++ b/sw/source/ui/inc/swcont.hxx
@@ -33,7 +33,7 @@
class SwContentType;
-//Reihenfolge und Anzahl mit ResIds abgleichen!!
+// synchronize order and number with ResIds!!
#define CONTENT_TYPE_OUTLINE 0
#define CONTENT_TYPE_TABLE 1
#define CONTENT_TYPE_FRAME 2
@@ -49,17 +49,17 @@ class SwContentType;
#define CONTENT_TYPE_MAX CONTENT_TYPE_DRAWOBJECT +1
-// Typen fuer das Globaldokument
+// types for global document
#define GLOBAL_CONTENT_REGION 100
#define GLOBAL_CONTENT_INDEX 101
#define GLOBAL_CONTENT_TEXT 102
#define GLOBAL_CONTENT_MAX 3
-// Strings fuer Kontextmenue
+// strings for context menus
#define CONTEXT_COUNT 12
#define GLOBAL_CONTEXT_COUNT 14
-// Modi fuer Drag 'n Drop
+// modes for Drag 'n Drop
#define REGION_MODE_NONE 0
#define REGION_MODE_LINK 1
#define REGION_MODE_EMBEDDED 2
@@ -94,12 +94,12 @@ public:
const String& GetName() const {return sContentName;}
int operator==(const SwContent& /*rCont*/) const
{
- //gleich sind sie nie, sonst fallen sie aus dem Array
+ // they're never equal, otherwise they'd fall out of the array
return sal_False;
}
int operator<(const SwContent& rCont) const
{
- //zuerst nach Position dann nach Name sortieren
+ // at first sort by position and then by name
return nYPosition != rCont.nYPosition ?
nYPosition < rCont.nYPosition :
sContentName < rCont.sContentName;;
diff --git a/sw/source/ui/inc/swdtflvr.hxx b/sw/source/ui/inc/swdtflvr.hxx
index 4e37f63..845a7ef 100644
--- a/sw/source/ui/inc/swdtflvr.hxx
+++ b/sw/source/ui/inc/swdtflvr.hxx
@@ -58,7 +58,7 @@ namespace nsTransferBufferType
const sal_uInt16 TRNSFR_DDELINK = 0x0010;
const sal_uInt16 TRNSFR_OLE = 0x0020;
const sal_uInt16 TRNSFR_INETFLD = 0x0040;
- const sal_uInt16 TRNSFR_DRAWING = 0x0081; //Drawing ist auch intern!
+ const sal_uInt16 TRNSFR_DRAWING = 0x0081; // drawing is internal too!
}
#define DATA_FLAVOR ::com::sun::star::datatransfer::DataFlavor
@@ -77,7 +77,7 @@ class SwTransferable : public TransferableHelper
const ViewShell *pCreatorView;
SwDocFac *pClpDocFac;
Graphic *pClpGraphic, *pClpBitmap, *pOrigGrf;
- INetBookmark *pBkmk; // URL und Beschreibung!
+ INetBookmark *pBkmk; // URL and description!
ImageMap *pImageMap;
INetImage *pTargetURL;
diff --git a/sw/source/ui/inc/swlbox.hxx b/sw/source/ui/inc/swlbox.hxx
index 265b5ad..6aab6cc 100644
--- a/sw/source/ui/inc/swlbox.hxx
+++ b/sw/source/ui/inc/swlbox.hxx
@@ -41,7 +41,7 @@ class Window;
SV_DECL_PTRARR_DEL(SwEntryLst, SwBoxEntry*, 10, 10)
/*--------------------------------------------------------------------
- Beschreibung: SwBoxEntry
+ Description: SwBoxEntry
--------------------------------------------------------------------*/
class SW_DLLPUBLIC SwBoxEntry
{
@@ -62,7 +62,7 @@ public:
};
/*--------------------------------------------------------------------
- Beschreibung: fuer ComboBoxen
+ Description: for combo boxes
--------------------------------------------------------------------*/
typedef sal_uInt16 SwComboBoxStyle;
diff --git a/sw/source/ui/inc/swuiidxmrk.hxx b/sw/source/ui/inc/swuiidxmrk.hxx
index c8ca13b..9b546fb 100644
--- a/sw/source/ui/inc/swuiidxmrk.hxx
+++ b/sw/source/ui/inc/swuiidxmrk.hxx
@@ -52,7 +52,7 @@ class SwWrtShell;
class SwTOXMgr;
class SwTOXMark;
/*--------------------------------------------------------------------
- Beschreibung: Markierung fuer Verzeichniseintrag einfuegen
+ Description: insert mark for index entry
--------------------------------------------------------------------*/
class SwIndexMarkFloatDlg;
class SwIndexMarkModalDlg;
diff --git a/sw/source/ui/inc/tabledlg.hxx b/sw/source/ui/inc/tabledlg.hxx
index 9b26c95..ec7c5ea 100644
--- a/sw/source/ui/inc/tabledlg.hxx
+++ b/sw/source/ui/inc/tabledlg.hxx
@@ -39,7 +39,7 @@ class SwTabCols;
struct TColumn;
/*-------------------------------------------------------
- Tabellendialog
+ table dialog
--------------------------------------------------------- */
class SwTableTabDlg : public SfxTabDialog
{
diff --git a/sw/source/ui/inc/tmpdlg.hxx b/sw/source/ui/inc/tmpdlg.hxx
index eca821e..dae38cf 100644
--- a/sw/source/ui/inc/tmpdlg.hxx
+++ b/sw/source/ui/inc/tmpdlg.hxx
@@ -34,7 +34,7 @@ class SfxItemSet;
class SwWrtShell;
/*--------------------------------------------------------------------
- Beschreibung: Der Tabdialog Traeger der TabPages
+ Description: the tab dialog carrier of TabPages
--------------------------------------------------------------------*/
class SwTemplateDlg: public SfxStyleDialog
{
diff --git a/sw/source/ui/inc/toxmgr.hxx b/sw/source/ui/inc/toxmgr.hxx
index 5c2aeb0..990f5e1 100644
--- a/sw/source/ui/inc/toxmgr.hxx
+++ b/sw/source/ui/inc/toxmgr.hxx
@@ -37,7 +37,7 @@ class SwWrtShell;
class SwForm;
/*--------------------------------------------------------------------
- Beschreibung: Manager fuer Verzeichnisfunktionalitaet
+ Description: manager for directory functionality
--------------------------------------------------------------------*/
//one single method will be sufficient to insert AND upate indexes
class SW_DLLPUBLIC SwTOXDescription
@@ -281,7 +281,7 @@ public:
explicit SwTOXMgr(SwWrtShell* pShell);
//
- // Methoden fuer Verzeichnismarkierungen
+ // methods for directory marks
//
void InsertTOXMark(const SwTOXMarkDescription& rDesc);
@@ -292,7 +292,7 @@ public:
void NextTOXMark(sal_Bool bSame=sal_False);
void PrevTOXMark(sal_Bool bSame=sal_False);
- // Aktuelle TOXmarks holen
+ // get current TOXmarks
sal_uInt16 GetTOXMarks();
sal_uInt16 GetTOXMarkCount();
SwTOXMark* GetTOXMark(sal_uInt16 nId);
@@ -300,7 +300,7 @@ public:
void SetCurTOXMark(sal_uInt16 nId);
//
- // Methoden fuer Verzeichnisse
+ // methods for directories
//
sal_Bool UpdateOrInsertTOX(const SwTOXDescription& rDesc, SwTOXBase** ppBase = 0, const SfxItemSet* pSet = 0);
@@ -310,7 +310,7 @@ public:
};
/*--------------------------------------------------------------------
- Beschreibung: Inlines
+ Description: inlines
--------------------------------------------------------------------*/
inline sal_uInt16 SwTOXMgr::GetTOXMarkCount()
{ return aCurMarks.Count(); }
diff --git a/sw/source/ui/inc/uiitems.hxx b/sw/source/ui/inc/uiitems.hxx
index f34a76b..1e7f55c 100644
--- a/sw/source/ui/inc/uiitems.hxx
+++ b/sw/source/ui/inc/uiitems.hxx
@@ -37,7 +37,7 @@ class SwNumRule;
class IntlWrapper;
/*--------------------------------------------------------------------
- Beschreibung: Container fuer FootNote
+ Description: container for FootNote
--------------------------------------------------------------------*/
class SW_DLLPUBLIC SwPageFtnInfoItem : public SfxPoolItem
{
diff --git a/sw/source/ui/inc/uinums.hxx b/sw/source/ui/inc/uinums.hxx
index c657178..59d910c 100644
--- a/sw/source/ui/inc/uinums.hxx
+++ b/sw/source/ui/inc/uinums.hxx
@@ -44,8 +44,8 @@ SV_DECL_PTRARR_DEL( _SwNumFmtsAttrs, SfxPoolItemPtr, 5,0 )
class SW_DLLPUBLIC SwNumRulesWithName
{
String aName;
- // die Formate der NumRule muessen! unabhaengig von einem Document sein
- // (Sie sollen immer vorhanden sein!)
+ // the NumRule's formats _have_ to be independent of a document
+ // (They should always be there!)
class SW_DLLPRIVATE _SwNumFmtGlobal
{
SwNumFmt aFmt;
@@ -87,7 +87,7 @@ public:
class SwBaseNumRules
{
public:
- enum { nMaxRules = MAX_NUM_RULES }; // zur Zeit 9 definierte Forms
+ enum { nMaxRules = MAX_NUM_RULES }; // currently 9 defined forms
protected:
SwNumRulesWithName *pNumRules[ MAX_NUM_RULES ];
String sFileName;
diff --git a/sw/source/ui/inc/uitool.hxx b/sw/source/ui/inc/uitool.hxx
index 0534680..53668f8 100644
--- a/sw/source/ui/inc/uitool.hxx
+++ b/sw/source/ui/inc/uitool.hxx
@@ -46,28 +46,28 @@ class SwTabCols;
class DateTime;
class SfxViewFrame;
-// Umschalten einer Metric
+// switch a metric
SW_DLLPUBLIC void SetMetric(MetricFormatter& rCtrl, FieldUnit eUnit);
-// BoxInfoAttribut fuellen
+// fill BoxInfoAttribut
SW_DLLPUBLIC void PrepareBoxInfo(SfxItemSet& rSet, const SwWrtShell& rSh);
// SfxItemSets <-> PageDesc
void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc );
void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet);
-// Auffuellen der Tabs mit DefaultTabs
+// fill tabs with default tabs
SW_DLLPUBLIC void MakeDefTabs(SwTwips nDefDist, SvxTabStopItem& rTabs);
-// DefaultTabs loeschen aus dem TabStopArray
+// erase DefaultTabs from TabStopArray
//void EraseDefTabs(SvxTabStopItem& rTabs);
-// Abstand zwischen dem 1. und zweitem Element ermitteln
+// determine space between 1st and 2nd element
SW_DLLPUBLIC sal_uInt16 GetTabDist(const SvxTabStopItem& rTabs);
-// erfrage ob im Set eine Sfx-PageDesc-Kombination vorliegt
-// und setze diesen im Set und loesche die Transport Items
-// (PageBreak & PageModel) aus dem Set
+// determine whether a Sfx-PageDesc combination exists in the set
+// and set this in the set and delete the transport items
+// (PageBreak & PageModel) from the set
void SwToSfxPageDescAttr( SfxItemSet& rSet );
void SfxToSwPageDescAttr( const SwWrtShell& rShell, SfxItemSet& rSet );
diff --git a/sw/source/ui/inc/utlui.hrc b/sw/source/ui/inc/utlui.hrc
index 80970bb..939644c 100644
--- a/sw/source/ui/inc/utlui.hrc
+++ b/sw/source/ui/inc/utlui.hrc
@@ -42,7 +42,7 @@
#define STR_HYPERCTRL_SEL (RC_UTLUI_BEGIN + 5)
#define STR_HYPERCTRL_HYP (RC_UTLUI_BEGIN + 6)
-// Namene der Inhaltstypen (RC_UTLUI_BEGIN + 7)
+// names of content types (RC_UTLUI_BEGIN + 7)
#define STR_CONTENT_TYPE_FIRST (RC_UTLUI_BEGIN + 8)
#define STR_CONTENT_TYPE_OUTLINE STR_CONTENT_TYPE_FIRST
#define STR_CONTENT_TYPE_TABLE (RC_UTLUI_BEGIN + 9)
diff --git a/sw/source/ui/inc/view.hxx b/sw/source/ui/inc/view.hxx
index 05108ed..75105bd 100644
--- a/sw/source/ui/inc/view.hxx
+++ b/sw/source/ui/inc/view.hxx
@@ -134,7 +134,7 @@ enum ShellModes
};
/*--------------------------------------------------------------------
- Beschreibung: Anwendung einer Vorlage
+ Description: apply a template
--------------------------------------------------------------------*/
struct SwApplyTemplate
{
@@ -163,11 +163,11 @@ struct SwApplyTemplate
};
/*--------------------------------------------------------------------
- Beschreibung: Sicht auf ein Dokument
+ Description: view of a document
--------------------------------------------------------------------*/
class SW_DLLPUBLIC SwView: public SfxViewShell
{
- //Messehack (MA,MBA)
+ // exhibition hack (MA,MBA)
friend void lcl_SelectShellForDrop( SwView &rView );
friend class TestTemplateItem;
@@ -176,7 +176,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
friend class SwView_Impl;
friend class SwClipboardChangeListener;
- //suchen & ersetzen
+ // search & replace
static SvxSearchDialog *pSrchDlg;
static SvxSearchItem *pSrchItem;
@@ -184,8 +184,8 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
static sal_uInt16 nWebInsertCtrlState;
static sal_uInt16 nInsertObjectCtrlState;
static sal_uInt16 nInsertFieldCtrlState;
- static sal_uInt16 nMoveType; // fuer Buttons unter dem Scrollbar (viewmdi)
- static sal_Int32 nActMark; // aktuelle Sprungmarke fuer unbenannte Merker
+ static sal_uInt16 nMoveType; // for buttons below the scrollbar (viewmdi)
+ static sal_Int32 nActMark; // current jump mark for unknown mark
static sal_Bool bExtra;
static sal_Bool bFound;
@@ -196,37 +196,34 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
SvxHtmlOptions aHTMLOpt;
- Timer aTimer; //Fuer verzoegerte ChgLnks waehrend
- //einer Aktion
- String aPageStr; //Statusanzeige, aktuelle Seite
+ Timer aTimer; // for delayed ChgLnks during an action
+ String aPageStr; // status view, current page
String sSwViewData,
//and the new cursor position if the user double click in the PagePreView
sNewCrsrPos;
// to support keyboard the number of the page to go to can be set too
sal_uInt16 nNewPage;
- Point aTabColFromDocPos; //Verschieben von Tabellenspalten aus
- //aus dem Dokument heraus.
+ Point aTabColFromDocPos; // moving table colmns out of the document
SwTxtNode * pNumRuleNodeFromDoc; // Moving indent of numrule #i23726#
- Size aDocSz; // aktuelle Dokumentgroesse
- Rectangle aVisArea; // sichtbarer Bereich
+ Size aDocSz; // current document size
+ Rectangle aVisArea; // visible region
SwEditWin *pEditWin;
SwWrtShell *pWrtShell;
- SfxShell *pShell; //aktuelle SubShell auf dem Dispatcher
+ SfxShell *pShell; // current SubShell at the dispatcher
FmFormShell *pFormShell; // DB-FormShell
- SwView_Impl *pViewImpl; // Impl-Daten fuer UNO + Basic
+ SwView_Impl *pViewImpl; // Impl-data for UNO + Basic
- SwScrollbar *pHScrollbar, // MDI Bedienelemente
+ SwScrollbar *pHScrollbar, // MDI control elements
*pVScrollbar;
- Window *pScrollFill; // Dummy-Window zum Fuellen der rechten
- // unteren Ecke, wenn beide Scrollbars
- // aktiv sind
+ Window *pScrollFill; // dummy window for filling the lower right edge
+ // when both scrollbars are active
SvxRuler *pHRuler,
*pVRuler;
@@ -236,7 +233,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
*pPageDownBtn;
SwNaviImageButton *pNaviBtn;
- SwGlossaryHdl *pGlosHdl; // Henkel Textbausteine
+ SwGlossaryHdl *pGlosHdl; // handle text block
SwDrawBase *pDrawActual;
const SwFrmFmt *pLastTableFormat;
@@ -254,7 +251,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
sal_uInt16 nPageCnt;
- // Aktueller Drawmode
+ // current draw mode
sal_uInt16 nDrawSfxId;
String sDrawCustom; //some drawing types are marked with strings!
sal_uInt16 nFormSfxId;
@@ -288,8 +285,8 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
bMakeSelectionVisible : 1 // transport the bookmark selection
;
- // Methoden fuers Suchen
- // Suchkontext setzen
+ // methods for searching
+ // set search context
SW_DLLPRIVATE sal_Bool SearchAndWrap(sal_Bool bApi = sal_False);
SW_DLLPRIVATE sal_Bool SearchAll(sal_uInt16* pFound = 0);
SW_DLLPRIVATE sal_uLong FUNC_Search( const SwSearchOptions& rOptions );
@@ -299,7 +296,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
SW_DLLPRIVATE sal_Bool IsTextTool() const;
- // Bedienelemente verwalten anlegen
+ // create control elements
SW_DLLPRIVATE void CreateBtns();
SW_DLLPRIVATE DECL_LINK( BtnPage, Button * );
@@ -320,7 +317,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
SW_DLLPRIVATE sal_Bool GetPageScrollUpOffset(SwTwips& rOff) const;
SW_DLLPRIVATE sal_Bool GetPageScrollDownOffset(SwTwips& rOff) const;
- // Scrollbar Movements
+ // scrollbar movements
SW_DLLPRIVATE long PageUp();
SW_DLLPRIVATE long PageDown();
SW_DLLPRIVATE long PageUpCrsr(sal_Bool bSelect);
@@ -337,7 +334,7 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
SW_DLLPRIVATE void CreatePageButtons(sal_Bool bShow);
- // Linguistik-Funktionen
+ // linguistics functions
SW_DLLPRIVATE void HyphenateDocument();
SW_DLLPRIVATE sal_Bool IsDrawTextHyphenate();
SW_DLLPRIVATE void HyphenateDrawText();
@@ -356,16 +353,16 @@ class SW_DLLPUBLIC SwView: public SfxViewShell
SW_DLLPRIVATE void SpellKontext(sal_Bool bOn = sal_True)
{ bCenterCrsr = bOn; bAllwaysShowSel = bOn; }
- // Methoden fuers Printing
+ // methods for printing
SW_DLLPRIVATE virtual SfxPrinter* GetPrinter( sal_Bool bCreate = sal_False );
SfxTabPage* CreatePrintOptionsPage( Window* pParent,
const SfxItemSet& rSet);
- // fuer Readonly-Umschaltung
+ // for readonly switching
SW_DLLPRIVATE virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint );
SW_DLLPRIVATE void _CheckReadonlyState();
SW_DLLPRIVATE void _CheckReadonlySelection();
- // Methode fuer PageDesc drehen
+ // method for rotating PageDesc
SW_DLLPRIVATE void SwapPageMargin(const SwPageDesc&, SvxLRSpaceItem& rLR);
SW_DLLPRIVATE void _SetZoom( const Size &rEditSz,
@@ -389,7 +386,7 @@ protected:
int GetSelectionType() const { return nSelectionType; }
void SetSelectionType(int nSet) { nSelectionType = nSet;}
- // fuer die SwWebView
+ // for SwWebView
void SetShell( SfxShell* pS ) { pShell = pS; }
void SetFormShell( FmFormShell* pSh ) { pFormShell = pSh; }
@@ -444,7 +441,7 @@ public:
bool IsValidSelectionForThesaurus() const;
String GetThesaurusLookUpText( bool bSelection ) const;
- // Shell sofort wechseln -> fuer GetSelectionObject
+ // immediately switch shell -> for GetSelectionObject
void StopShellTimer();
inline SwWrtShell& GetWrtShell () const { return *pWrtShell; }
@@ -457,7 +454,7 @@ public:
void ScannerEventHdl( const ::com::sun::star::lang::EventObject& rEventObject );
#endif
- //Handler fuer Textbausteine an die Textshell rausreichen, gfs. anlegen
+ // hand the handler for text blocks to the shell; create if applicable
SwGlossaryHdl* GetGlosHdl();
inline const Rectangle& GetVisArea() const { return aVisArea; }
@@ -509,7 +506,7 @@ public:
sal_Bool HandleWheelCommands( const CommandEvent& );
- // Rahmen einfuegen
+ // insert frames
void InsFrmMode(sal_uInt16 nCols);
void SetZoom( SvxZoomType eZoomType, short nFactor = 100, sal_Bool bViewOnly = sal_False);
@@ -563,7 +560,7 @@ public:
void StateStatusLine(SfxItemSet&);
- // Funktionen fuer Drawing
+ // functions for drawing
void SetDrawFuncPtr(SwDrawBase* pFuncPtr);
inline SwDrawBase* GetDrawFuncPtr(/*sal_Bool bBuf = sal_False*/) const { return pDrawActual; }
void GetDrawState(SfxItemSet &rSet);
@@ -573,7 +570,7 @@ public:
inline sal_Bool IsDrawSelMode() { return bDrawSelMode; }
void SetSelDrawSlot();
inline void FlipDrawSelMode() { bDrawSelMode = !bDrawSelMode; }
- void NoRotate(); // Rotate-Mode abschalten
+ void NoRotate(); // turn off rotate mode
sal_Bool EnterDrawTextMode(const Point& aDocPos);
void LeaveDrawCreate() { nDrawSfxId = nFormSfxId = USHRT_MAX; sDrawCustom.Erase();}
sal_Bool IsDrawMode() { return (nDrawSfxId != USHRT_MAX || nFormSfxId != USHRT_MAX); }
@@ -587,30 +584,30 @@ public:
void StateTabWin(SfxItemSet&);
- // Attribute haben sich geaendert
+ // attributes have changed
DECL_LINK( AttrChangedNotify, SwWrtShell * );
// form control has been activated
DECL_LINK( FormControlActivated, FmFormShell* );
- // Links bearbeiten
+ // edit links
void EditLinkDlg();
void AutoCaption(const sal_uInt16 nType, const SvGlobalName *pOleId = 0);
void InsertCaption(const InsCaptionOpt *pOpt);
- // Async Aufruf durch Core
+ // Async call by Core
void UpdatePageNums(sal_uInt16 nPhyNum, sal_uInt16 nVirtNum, const String& rPgStr);
String GetPageStr(sal_uInt16 nPhyNum, sal_uInt16 nVirtNum, const String& rPgStr);
- // Shell rausreichen
+ // hand over Shell
SfxShell *GetCurShell() { return pShell; }
SwDocShell *GetDocShell();
inline const SwDocShell *GetDocShell() const;
inline FmFormShell *GetFormShell() { return pFormShell; }
inline const FmFormShell *GetFormShell() const { return pFormShell; }
- //damit in DToren der SubShells ggf. pShell zurueckgesetzt werden kann
+ // so that in the SubShells' DTors pShell can be reset if applicable
void ResetSubShell() { pShell = 0; }
virtual void WriteUserData(String &, sal_Bool bBrowse = sal_False );
diff --git a/sw/source/ui/inc/workctrl.hxx b/sw/source/ui/inc/workctrl.hxx
index b014472..2707794 100644
--- a/sw/source/ui/inc/workctrl.hxx
+++ b/sw/source/ui/inc/workctrl.hxx
@@ -36,8 +36,8 @@
class PopupMenu;
class SwView;
-// doppelter Eintrag! hrc und hxx
-// diese Ids bestimmen, was die Buttons unter dem Scrollbar tun
+// double entry! hrc and hxx
+// these Ids say what the buttons below the scrollbar are doing
#define NID_START 20000
#define NID_NEXT 20000
#define NID_PREV 20001
@@ -186,7 +186,7 @@ class SwNaviImageButton : public ImageButton
};
//----------------------------------------------------------------------------
-// Die ImageButtons muessen sich bei Bedarf den HelpText selbst setzen
+// ImageButtons have to set the HelpText themselves if needed
//----------------------------------------------------------------------------
class SwHlpImageButton : public ImageButton
diff --git a/sw/source/ui/inc/wrap.hxx b/sw/source/ui/inc/wrap.hxx
index 07ec857..689de3c 100644
--- a/sw/source/ui/inc/wrap.hxx
+++ b/sw/source/ui/inc/wrap.hxx
@@ -56,7 +56,7 @@ public:
/*--------------------------------------------------------------------
- Beschreibung: Umlauf-TabPage
+ Description: circulation TabPage
--------------------------------------------------------------------*/
class SwWrapTabPage: public SfxTabPage
diff --git a/sw/source/ui/inc/wrtsh.hxx b/sw/source/ui/inc/wrtsh.hxx
index e6917f2..ac1ef56 100644
--- a/sw/source/ui/inc/wrtsh.hxx
+++ b/sw/source/ui/inc/wrtsh.hxx
@@ -70,17 +70,17 @@ namespace com { namespace sun { namespace star { namespace util {
typedef sal_Int32 SelectionType;
namespace nsSelectionType
{
- const SelectionType SEL_TXT = CNT_TXT; // Text, niemals auch Rahmen 0x0001
- const SelectionType SEL_GRF = CNT_GRF; // Grafik 0x0002
- const SelectionType SEL_OLE = CNT_OLE; // OLE 0x0010
- const SelectionType SEL_FRM = 0x000020; // Rahmen, keine Inhaltsform
- const SelectionType SEL_NUM = 0x000040; // NumListe
- const SelectionType SEL_TBL = 0x000080; // Cursor steht in Tabelle
- const SelectionType SEL_TBL_CELLS = 0x000100; // Tabellenzellen sind selektiert
- const SelectionType SEL_DRW = 0x000200; // Zeichenobjekte (Rechteck, Kreis...)
- const SelectionType SEL_DRW_TXT = 0x000400; // Draw-Textobjekte im Editmode
- const SelectionType SEL_BEZ = 0x000800; // Bezierobjekte editieren
- const SelectionType SEL_DRW_FORM = 0x001000; // Zeichenobjekte: DB-Forms
+ const SelectionType SEL_TXT = CNT_TXT; // text, never frames too 0x0001
+ const SelectionType SEL_GRF = CNT_GRF; // graphic 0x0002
+ const SelectionType SEL_OLE = CNT_OLE; // OLE 0x0010
+ const SelectionType SEL_FRM = 0x000020; // frame, no content type
+ const SelectionType SEL_NUM = 0x000040; // NumList
+ const SelectionType SEL_TBL = 0x000080; // cursor is in table
+ const SelectionType SEL_TBL_CELLS = 0x000100; // table cells are selected
+ const SelectionType SEL_DRW = 0x000200; // drawing objects (rectangle, circle...)
+ const SelectionType SEL_DRW_TXT = 0x000400; // draw-textobjects in edit mode
+ const SelectionType SEL_BEZ = 0x000800; // edit ornament objects
+ const SelectionType SEL_DRW_FORM = 0x001000; // drawing objects: DB-Forms
const SelectionType SEL_FOC_FRM_CTRL = 0x002000; // a form control is focused. Neither set nor evaluated by the SwWrtShell itself, only by it's clients.
const SelectionType SEL_MEDIA = 0x004000; // Media object
const SelectionType SEL_EXTRUDED_CUSTOMSHAPE = 0x008000; // extruded custom shape
@@ -115,11 +115,10 @@ public:
SELECTFUNC fnEndDrag;
SELECTFUNC fnKillSel;
- // Alle Selektionen aufheben
+ // reset all selections
long ResetSelect( const Point *, sal_Bool );
- //setzt den Cursorstack nach dem Bewegen mit PageUp/-Down
- //zurueck, falls ein Stack aufgebaut ist
+ // resets the cursorstack after movement with PageUp/-Down if a stack is built up
inline void ResetCursorStack();
SelectionType GetSelectionType() const;
@@ -131,7 +130,7 @@ public:
void EndSelect();
sal_Bool IsInSelect() const { return bInSelect; }
void SetInSelect(sal_Bool bSel = sal_True) { bInSelect = bSel; }
- // Liegt eine Text- oder Rahmenselektion vor?
+ // is there a text- or frameselection?
sal_Bool HasSelection() const { return SwCrsrShell::HasSelection() ||
IsMultiSelection() || IsSelFrmMode() || IsObjSelected(); }
sal_Bool Pop( sal_Bool bOldCrsr = sal_True );
@@ -162,31 +161,30 @@ public:
void EnterSelFrmMode(const Point *pStartDrag = 0);
void LeaveSelFrmMode();
sal_Bool IsSelFrmMode() const { return bLayoutMode; }
- // Selektion von Rahmen aufheben
+ // reset selection of frames
void UnSelectFrm();
void Invalidate();
- // Tabellenzellen selektieren fuer Bearbeiten von Formeln in der Ribbonbar
+ // select table cells for editing of formulas in the ribbonbar
inline void SelTblCells( const Link &rLink, sal_Bool bMark = sal_True );
inline void EndSelTblCells();
- //Wortweisen oder zeilenweisen Selektionsmodus verlassen. Wird
- //in der Regel in MB-Up gerufen.
+ // leave per word or per line selection mode. Is usually called in MB-Up.
sal_Bool IsExtSel() const { return bSelWrd || bSelLn; }
- // erfrage, ob der akt. fnDrag - Pointer auf BeginDrag gesetzt ist
- // Wird fuer MouseMove gebraucht, um die Bugs 55592/55931 zu umgehen.
+ // query whether the active fnDrag pointer is set to BeginDrag
+ // is needed for MouseMove to work around bugs 55592/55931
inline sal_Bool Is_FnDragEQBeginDrag() const;
- //Basisabfragen
+ // base requests
sal_Bool IsInWrd() { return IsInWord(); }
sal_Bool IsSttWrd() { return IsStartWord(); }
sal_Bool IsEndWrd();
sal_Bool IsSttOfPara() const { return IsSttPara(); }
sal_Bool IsEndOfPara() const { return IsEndPara(); }
- //Word bzw. Satz selektieren.
+ // select word / sentense
sal_Bool SelNearestWrd();
sal_Bool SelWrd (const Point * = 0, sal_Bool bProp=sal_False );
// #i32329# Enhanced selection
@@ -195,7 +193,7 @@ public:
// <--
long SelAll();
- //Basiscursortravelling
+ // basecursortravelling
typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
sal_Bool SimpleMove( FNSimpleMove, sal_Bool bSelect );
@@ -242,7 +240,7 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
sal_Bool SelectTxtAttr( sal_uInt16 nWhich, const SwTxtAttr* pAttr = 0 );
- // Spaltenweise Spruenge
+ // per column jumps
sal_Bool StartOfColumn ( sal_Bool bSelect = sal_False );
sal_Bool EndOfColumn ( sal_Bool bSelect = sal_False );
sal_Bool StartOfNextColumn ( sal_Bool bSelect = sal_False );
@@ -250,18 +248,18 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
sal_Bool StartOfPrevColumn ( sal_Bool bSelect = sal_False );
sal_Bool EndOfPrevColumn ( sal_Bool bSelect = sal_False );
- // setze den Cursor auf die Seite "nPage" an den Anfang
- // zusaetzlich zu der gleichnamigen Implementierung in crsrsh.hxx
- // werden hier alle bestehenden Selektionen vor dem Setzen des
- // Cursors aufgehoben
+ // set the cursor to page "nPage" at the beginning
+ // additionally to a identically named implementation in crsrsh.hxx
+ // here all existing selections are being reset before setting the
+ // cursor
sal_Bool GotoPage( sal_uInt16 nPage, sal_Bool bRecord );
- //setzen des Cursors; merken der alten Position fuer Zurueckblaettern.
+ // setting the cursor; remember the old position for turning back
DECL_LINK( ExecFlyMac, void * );
sal_Bool PageCrsr(SwTwips lOffset, sal_Bool bSelect);
- // Felder Update
+ // update fields
void UpdateInputFlds( SwInputFieldList* pLst = 0, sal_Bool bOnlyInSel = sal_False );
void NoEdit(sal_Bool bHideCrsr = sal_True);
@@ -274,14 +272,13 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
// change current data base and notify
void ChgDBData(const SwDBData& SwDBData);
- // Loeschen
+ // delete
long DelToEndOfLine();
long DelToStartOfLine();
long DelLine();
long DelLeft();
- // loescht auch Rahmen bzw. setzt den Cursor in den Rahmen,
- // wenn bDelFrm == sal_False ist
+ // also deletes the frame or sets the cursor in the frame when bDelFrm == sal_False
long DelRight();
long DelToEndOfPara();
long DelToStartOfPara();
@@ -290,10 +287,10 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
long DelNxtWord();
long DelPrvWord();
- // Prueft, ob eine Wortselektion vorliegt.
- // Gemaess den Regeln fuer intelligentes Cut / Paste
- // werden umgebende Spaces rausgeschnitten.
- // Liefert Art der Wortselektion zurueck (siehe enum)
+ // checks whether a word selection exists.
+ // According to the rules for intelligent Cut / Paste
+ // surrounding spaces are cut out.
+ // returns type of word selection (see enum)
enum word {
NO_WORD = 0,
WORD_SPACE_BEFORE = 1,
@@ -302,10 +299,10 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
};
int IntelligentCut(int nSelectionType, sal_Bool bCut = sal_True);
- // Editieren
+ // edit
void Insert(SwField &);
void Insert(const String &);
- // Graphic
+ // graphic
void Insert( const String &rPath, const String &rFilter,
const Graphic &, SwFlyFrmAttrMgr * = 0,
sal_Bool bRule = sal_False );
@@ -318,11 +315,11 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
void SplitNode( sal_Bool bAutoFormat = sal_False, sal_Bool bCheckTableStart = sal_True );
sal_Bool CanInsert();
- // Verzeichnisse
+ // indexes
void InsertTableOf(const SwTOXBase& rTOX, const SfxItemSet* pSet = 0);
sal_Bool UpdateTableOf(const SwTOXBase& rTOX, const SfxItemSet* pSet = 0);
- // Numerierung und Bullets
+ // numbering and bullets
/**
Turns on numbering or bullets.
@@ -335,14 +332,14 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
void BulletOn();
//OLE
- void InsertObject( /*SvInPlaceObjectRef *pObj, */ // != 0 fuer Clipboard
+ void InsertObject( /*SvInPlaceObjectRef *pObj, */ // != 0 for clipboard
const svt::EmbeddedObjectRef&,
- SvGlobalName *pName = 0, // != 0 entspr. Object erzeugen.
+ SvGlobalName *pName = 0, // != 0 create object accordingly
sal_Bool bActivate = sal_True,
- sal_uInt16 nSlotId = 0); // SlotId fuer Dialog
+ sal_uInt16 nSlotId = 0); // SlotId for dialog
sal_Bool InsertOleObject( const svt::EmbeddedObjectRef& xObj, SwFlyFrmFmt **pFlyFrmFmt = 0 );
- void LaunchOLEObj( long nVerb = 0 ); // Server starten
+ void LaunchOLEObj( long nVerb = 0 ); // start server
sal_Bool IsOLEObj() const { return GetCntType() == CNT_OLE;}
virtual void MoveObjectIfActive( svt::EmbeddedObjectRef& xObj, const Point& rOffset );
virtual void CalcAndSetScale( svt::EmbeddedObjectRef& xObj,
@@ -351,12 +348,12 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
virtual void ConnectObj( svt::EmbeddedObjectRef& xIPObj, const SwRect &rPrt,
const SwRect &rFrm );
- // Vorlagen und Formate
+ // styles and formats
- // enum gibt an, was geschehen soll, wenn das Style nicht gefunden wurde
- enum GetStyle { GETSTYLE_NOCREATE, // keins anlegen
- GETSTYLE_CREATESOME, // falls auf PoolId mapt anlegen
- GETSTYLE_CREATEANY }; // ggfs Standard returnen
+ // enum tells when should happen when the style was not found
+ enum GetStyle { GETSTYLE_NOCREATE, // create none
+ GETSTYLE_CREATESOME, // if on PoolId create mapt
+ GETSTYLE_CREATEANY }; // return standard if applicable
SwTxtFmtColl* GetParaStyle(const String &rCollName,
GetStyle eCreate = GETSTYLE_NOCREATE);
@@ -368,7 +365,7 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
String GetCurPageStyle( const sal_Bool bCalcFrm = sal_True ) const;
- // Aktuelle Vorlage anhand der geltenden Attribute aendern
+ // change current style using the attributes in effect
void QuickUpdateStyle();
enum DoType { UNDO, REDO, REPEAT };
@@ -378,7 +375,7 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
String GetRepeatString() const;
sal_uInt16 GetDoStrings( DoType eDoType, SfxStringListItem& rStrLstItem ) const;
- //Suchen oder Ersetzen
+ // search and replace
sal_uLong SearchPattern(const com::sun::star::util::SearchOptions& rSearchOpt,
sal_Bool bSearchInNotes,
SwDocPositions eStart, SwDocPositions eEnde,
@@ -399,23 +396,23 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
void AutoCorrect( SvxAutoCorrect& rACorr, sal_Unicode cChar = ' ' );
- // Aktion vor Cursorbewegung
- // Hebt gfs. Selektionen auf, triggert Timer und GCAttr()
+ // action ahead of cursor movement
+ // resets selection if applicable, triggers timer and GCAttr()
void MoveCrsr( sal_Bool bWithSelect = sal_False );
- // Eingabefelder updaten
+ // update input fields
sal_Bool StartInputFldDlg(SwField*, sal_Bool bNextButton, Window* pParentWin = 0, ByteString* pWindowState = 0);
// update DropDown fields
sal_Bool StartDropDownFldDlg(SwField*, sal_Bool bNextButton, ByteString* pWindowState = 0);
- //"Handler" fuer Anederungen an der DrawView - fuer Controls.
+ //"Handler" for changes at DrawView - for controls.
virtual void DrawSelChanged( );
- // springe zum Bookmark und setze die "Selections-Flags" wieder richtig
+ // jump to bookmark and set the "selctions-flags" correctly again
sal_Bool GotoMark( const ::sw::mark::IMark* const pMark );
sal_Bool GotoMark( const ::sw::mark::IMark* const pMark, sal_Bool bSelect, sal_Bool bStart );
sal_Bool GotoMark( const ::rtl::OUString& rName );
- sal_Bool GoNextBookmark(); // sal_True, wenn's noch eine gab
+ sal_Bool GoNextBookmark(); // sal_True when there still was one
sal_Bool GoPrevBookmark();
bool GotoFieldmark(::sw::mark::IFieldmark const * const pMark);
@@ -426,46 +423,44 @@ typedef sal_Bool (SwWrtShell:: *FNSimpleMove)();
// on graphics
sal_Bool SelectNextPrevHyperlink( sal_Bool bNext = sal_True );
- // Zugehoerige SwView ermitteln
+ // determine corresponding SwView
const SwView& GetView() const { return rView; }
SwView& GetView() { return rView; }
- //Weil es sonst keiner macht, gibt es hier eine ExecMacro()
+ // Because nobody else is doing it, here is a ExecMacro()
void ExecMacro( const SvxMacro& rMacro, String* pRet = 0, SbxArray* pArgs = 0 );
- // rufe ins dunkle Basic/JavaScript
+ // call into the dark Basic/JavaScript
sal_uInt16 CallEvent( sal_uInt16 nEvent, const SwCallMouseEvent& rCallEvent,
sal_Bool bCheckPtr = sal_False, SbxArray* pArgs = 0,
const Link* pCallBack = 0 );
- // ein Klick aus das angegebene Feld. Der Cursor steht auf diesem.
- // Fuehre die vor definierten Aktionen aus.
+ // a click at the given field. the cursor is on it.
+ // execute the predefined actions.
void ClickToField( const SwField& rFld );
void ClickToINetAttr( const SwFmtINetFmt& rItem, sal_uInt16 nFilter = URLLOAD_NOFILTER );
sal_Bool ClickToINetGrf( const Point& rDocPt, sal_uInt16 nFilter = URLLOAD_NOFILTER );
inline sal_Bool IsInClickToEdit() const ;
- // fall ein URL-Button selektiert ist, dessen URL returnen, ansonsten
- // einen LeerString
+ // if a URL-Button is selected, return its URL; otherwise an empty string
sal_Bool GetURLFromButton( String& rURL, String& rDescr ) const;
void NavigatorPaste( const NaviContentBookmark& rBkmk,
const sal_uInt16 nAction );
- // die Core erzeugt eine Selektion, das SttSelect muss gerufen werden
+ // Core creates a selection, SttSelect has to be called
virtual void NewCoreSelection();
virtual void ApplyViewOptions( const SwViewOption &rOpt );
- // autom. Update von Vorlagen
+ // automatic update of styles
void AutoUpdateFrame(SwFrmFmt* pFmt, const SfxItemSet& rStyleSet);
void AutoUpdatePara(SwTxtFmtColl* pColl, const SfxItemSet& rStyleSet);
- // Link fuers einfuegen von Bereichen uebers Drag&Drop/Clipboard
+ // link for inserting ranges via Drag&Drop/Clipboard
DECL_STATIC_LINK( SwWrtShell, InsertRegionDialog, SwSectionData* );
- //ctoren, der erstere ist eine Art kontrollierter copy ctor fuer weitere
- //Sichten auf ein Dokument
+ // ctor, the first one is a kind of a controlled copy ctor for more views of a document
SwWrtShell( SwWrtShell&, Window *pWin, SwView &rShell);
SwWrtShell( SwDoc& rDoc, Window *pWin, SwView &rShell,
const SwViewOption *pViewOpt = 0);
@@ -515,7 +510,7 @@ private:
{}
} *pModeStack;
- // Cursor bei PageUp / -Down mitnehmen
+ // carry cursor along when PageUp / -Down
enum PageMove
{
MV_NO,
@@ -554,7 +549,7 @@ private:
SW_DLLPRIVATE sal_Bool PushCrsr(SwTwips lOffset, sal_Bool bSelect);
SW_DLLPRIVATE sal_Bool PopCrsr(sal_Bool bUpdate, sal_Bool bSelect = sal_False);
- // ENDE Cursor bei PageUp / -Down mitnehmen
+ // take END cursor along when PageUp / -Down
SW_DLLPRIVATE sal_Bool _SttWrd();
SW_DLLPRIVATE sal_Bool _EndWrd();
SW_DLLPRIVATE sal_Bool _NxtWrd();
@@ -568,7 +563,7 @@ private:
sal_Bool _FwdPara();
SW_DLLPRIVATE sal_Bool _BwdPara();
- // Selektionen
+ // selections
sal_Bool bIns :1;
sal_Bool bInSelect :1;
sal_Bool bExtMode :1;
@@ -580,7 +575,7 @@ private:
sal_Bool bSelWrd :1;
sal_Bool bSelLn :1;
sal_Bool bIsInClickToEdit:1;
- sal_Bool bClearMark :1; // Selektion fuer ChartAutoPilot nicht loeschen
+ sal_Bool bClearMark :1; // don't delete selection for ChartAutoPilot
sal_Bool mbRetainSelection :1; // Do not remove selections
Point aStart;
@@ -588,7 +583,7 @@ private:
SELECTFUNC fnLeaveSelect;
- //setzt den Cursorstack nach dem Bewegen mit PageUp/-Down zurueck.
+ // resets the cursor stack after movement by PageUp/-Down
SW_DLLPRIVATE void _ResetCursorStack();
SW_DLLPRIVATE void SttDragDrop(Timer *);
@@ -606,13 +601,12 @@ private:
SW_DLLPRIVATE long ExtSelWrd(const Point *, sal_Bool bProp=sal_False );
SW_DLLPRIVATE long ExtSelLn(const Point *, sal_Bool bProp=sal_False );
- //Verschieben von Text aus Drag and Drop; Point ist
- //Destination fuer alle Selektionen.
+ // move text from Drag and Drop; Point is destination for all selections.
SW_DLLPRIVATE long MoveText(const Point *, sal_Bool bProp=sal_False );
SW_DLLPRIVATE long BeginFrmDrag(const Point *, sal_Bool bProp=sal_False );
- //nach SSize/Move eines Frames Update; Point ist Destination.
+ // after SSize/Move of a frame update; Point is destination.
SW_DLLPRIVATE long UpdateLayoutFrm(const Point *, sal_Bool bProp=sal_False );
SW_DLLPRIVATE long SttLeaveSelect(const Point *, sal_Bool bProp=sal_False );
commit 471dae3de728c80fbf0cafe863a0e19b27260e4d
Author: Martin Kepplinger <martinkepplinger at eml.cc>
Date: Thu Apr 21 18:12:29 2011 +0200
Translate german comments
Translate german code comments to english!
This is contributed under the terms of the MPL 1.1 / GPLv3+ / LGPLv3+ triple
license.
diff --git a/sw/source/ui/inc/formedt.hxx b/sw/source/ui/inc/formedt.hxx
index 2d07f60..5372c96 100644
--- a/sw/source/ui/inc/formedt.hxx
+++ b/sw/source/ui/inc/formedt.hxx
@@ -44,7 +44,7 @@ class SwWrtShell;
class SwForm;
/*--------------------------------------------------------------------
- Beschreibung: Markierung fuer Verzeichniseintrag einfuegen
+ Description: insert marker for index entry
--------------------------------------------------------------------*/
class SwIdxFormDlg : public SvxStandardDialog
{
diff --git a/sw/source/ui/inc/frmdlg.hxx b/sw/source/ui/inc/frmdlg.hxx
index 75f3f47..792b629 100644
--- a/sw/source/ui/inc/frmdlg.hxx
+++ b/sw/source/ui/inc/frmdlg.hxx
@@ -34,7 +34,7 @@
class SwWrtShell;
/*--------------------------------------------------------------------
- Beschreibung: Rahmendialog
+ Description: frame dialog
--------------------------------------------------------------------*/
class SwFrmDlg : public SfxTabDialog
{
diff --git a/sw/source/ui/inc/frmmgr.hxx b/sw/source/ui/inc/frmmgr.hxx
index 15a1f71..2c8560b 100644
--- a/sw/source/ui/inc/frmmgr.hxx
+++ b/sw/source/ui/inc/frmmgr.hxx
@@ -70,18 +70,18 @@ class SW_DLLPUBLIC SwFlyFrmAttrMgr
sal_Bool bIsInVerticalL2R;
// <--
- // interne Verrechnung fuer Umrandung
+ // internal calculation for borders
SW_DLLPRIVATE SwTwips CalcTopSpace();
SW_DLLPRIVATE SwTwips CalcBottomSpace();
SW_DLLPRIVATE SwTwips CalcLeftSpace();
SW_DLLPRIVATE SwTwips CalcRightSpace();
- SW_DLLPRIVATE void _UpdateFlyFrm(); //Nacharbeit nach Einfuegen oder Update
+ SW_DLLPRIVATE void _UpdateFlyFrm(); // post-treatment after insertation or update
public:
SwFlyFrmAttrMgr( sal_Bool bNew, SwWrtShell* pSh, sal_uInt8 nType );
- //CopyCtor fuer die Dialoge, zum Pruefen der Metrics
+ //CopyCtor for dialogs to check the metrics
SwFlyFrmAttrMgr( sal_Bool bNew, SwWrtShell *pSh, const SfxItemSet &rSet );
inline SwWrtShell* GetShell() { return pOwnSh; }
@@ -92,14 +92,14 @@ public:
void SetHorzOrientation(sal_Int16 eOrient);
void SetVertOrientation(sal_Int16 eOrient);
- // Absolute Position
+ // absolute position
void SetAbsPos(const Point& rLPoint);
- // Relative Position vom Anker
+ // anchor's relative position
void SetPos(const Point& rLPoint);
inline Point GetPos() const;
- // Groesse
+ // size
void SetSize(const Size& rLSize);
inline const Size& GetSize() const;
@@ -107,7 +107,7 @@ public:
void SetHeightSizeType(SwFrmSize eType);
- // Abstand zum Inhalt
+ // space to content
void SetLRSpace( long nLeft = LONG_MAX,
long nRight = LONG_MAX );
void SetULSpace( long nTop = LONG_MAX,
@@ -115,25 +115,25 @@ public:
void SetCol( const SwFmtCol &rCol);
- // Attribute aendern und erfragen
+ // change and query attributes
void UpdateAttrMgr();
void UpdateFlyFrm();
- // neuen Rahmen erzeugen
+ // create new frame
sal_Bool InsertFlyFrm();
void InsertFlyFrm(RndStdIds eAnchorType,
const Point &rPos,
const Size &rSize,
sal_Bool bAbsPos = sal_False);
- // Metriken pruefen und aendern
+ // check and change metrics
void ValidateMetrics(SvxSwFrameValidation& rVal,
const SwPosition* pToCharCntntPos,
sal_Bool bOnlyPercentRefValue = sal_False);
void DelAttr(sal_uInt16 nId);
- // Set rausreichen
+ // reach out the set
inline const SfxItemSet &GetAttrSet() const { return aSet; }
inline SfxItemSet &GetAttrSet() { return aSet; }
void SetAttrSet(const SfxItemSet& rSet);
diff --git a/sw/source/ui/inc/frmpage.hxx b/sw/source/ui/inc/frmpage.hxx
index 2cc63a3..be71a96 100644
--- a/sw/source/ui/inc/frmpage.hxx
+++ b/sw/source/ui/inc/frmpage.hxx
@@ -48,11 +48,11 @@ struct FrmMap;
struct SwPosition;
/*--------------------------------------------------------------------
- Beschreibung: Rahmendialog
+ Description: frame dialog
--------------------------------------------------------------------*/
class SwFrmPage: public SfxTabPage
{
- // Size
+ // size
FixedLine aSizeFL;
FixedText aWidthFT;
FixedText aWidthAutoFT;
@@ -67,7 +67,7 @@ class SwFrmPage: public SfxTabPage
CheckBox aFixedRatioCB;
PushButton aRealSizeBT;
- // Anker
+ // anchor
FixedLine aTypeSepFL;
FixedLine aTypeFL;
RadioButton aAnchorAtPageRB;
@@ -76,7 +76,7 @@ class SwFrmPage: public SfxTabPage
RadioButton aAnchorAsCharRB;
RadioButton aAnchorAtFrameRB;
- // Position
+ // position
FixedLine aPositionFL;
FixedText aHorizontalFT;
ListBox aHorizontalDLB;
@@ -94,7 +94,7 @@ class SwFrmPage: public SfxTabPage
// OD 02.10.2003 #i18732# - check box for new option 'FollowTextFlow'
CheckBox aFollowTextFlowCB;
- // Example
+ // example
SvxSwFrameExample aExampleWN;
//'string provider'
@@ -125,7 +125,7 @@ class SwFrmPage: public SfxTabPage
// to character anchored objects.
const SwPosition* mpToCharCntntPos;
- // Die alten Ausrichtungen
+ // old alignment
short nOldH;
short nOldHRel;
short nOldV;
@@ -157,7 +157,7 @@ class SwFrmPage: public SfxTabPage
DECL_LINK( AutoWidthClickHdl, void* );
DECL_LINK( AutoHeightClickHdl, void* );
- // Beispiel aktualisieren
+ // update example
void UpdateExample();
DECL_LINK( ModifyHdl, Edit * );
@@ -206,7 +206,7 @@ public:
class SwGrfExtPage: public SfxTabPage
{
- // Spiegeln
+ // mirror
FixedLine aMirrorFL;
CheckBox aMirrorVertBox;
CheckBox aMirrorHorzBox;
@@ -227,7 +227,7 @@ class SwGrfExtPage: public SfxTabPage
sal_Bool bHtmlMode;
- // Handler fuer Spiegeln
+ // handler for mirroring
DECL_LINK( MirrorHdl, CheckBox * );
DECL_LINK( BrowseHdl, Button * );
@@ -249,7 +249,7 @@ public:
class SwFrmURLPage : public SfxTabPage
{
- //Hyperlink
+ // hyperlink
FixedLine aHyperLinkFL;
FixedText aURLFT;
Edit aURLED;
@@ -259,7 +259,7 @@ class SwFrmURLPage : public SfxTabPage
FixedText aFrameFT;
ComboBox aFrameCB;
- //Image map
+ // image map
FixedLine aImageFL;
CheckBox aServerCB;
CheckBox aClientCB;
diff --git a/sw/source/ui/inc/gloshdl.hxx b/sw/source/ui/inc/gloshdl.hxx
index ebc869f..3e26b9e 100644
--- a/sw/source/ui/inc/gloshdl.hxx
+++ b/sw/source/ui/inc/gloshdl.hxx
@@ -78,8 +78,8 @@ public:
sal_Bool CopyOrMove( const String& rSourceGroupName, String& rSourceShortName,
const String& rDestGroupName, const String& rLongName, sal_Bool bMove );
sal_Bool HasShortName(const String &rShortName) const;
- //wird NewGlossary vom Basic gerufen, dann soll dir zuvor eingestellte
- //Gruppe ggf. neu erstellt werden
+ // when NewGlossary is called from Basic then the previously set group should
+ // be newly created if applicable.
sal_Bool NewGlossary(const String &rName, const String &rShortName,
sal_Bool bApiCall = sal_False, sal_Bool bNoAttr = sal_False );
sal_Bool DelGlossary(const String&);
@@ -100,7 +100,7 @@ public:
sal_Bool IsReadOnly( const String* = 0 ) const;
sal_Bool IsOld() const;
- sal_Bool FindGroupName(String & rGroup); // Gruppe ohne Pfadindex finden
+ sal_Bool FindGroupName(String & rGroup); // find group without path index
sal_Bool ImportGlossaries( const String& rName );
diff --git a/sw/source/ui/inc/gloslst.hxx b/sw/source/ui/inc/gloslst.hxx
index d216b23..58be8b9 100644
--- a/sw/source/ui/inc/gloslst.hxx
+++ b/sw/source/ui/inc/gloslst.hxx
@@ -43,8 +43,8 @@ struct AutoTextGroup
sal_uInt16 nCount;
String sName;
String sTitle;
- String sLongNames; // durch 0x0A getrennte Langnamen
- String sShortNames; // durch 0x0A getrennte Kurznamen
+ String sLongNames; // by 0x0A seperated long names
+ String sShortNames; // by 0x0A seperated short names
DateTime aDateModified;
};
diff --git a/sw/source/ui/inc/hyp.hxx b/sw/source/ui/inc/hyp.hxx
index d8d49e0..e9f3018 100644
--- a/sw/source/ui/inc/hyp.hxx
+++ b/sw/source/ui/inc/hyp.hxx
@@ -41,12 +41,12 @@ private:
::com::sun::star::uno::Reference<
::com::sun::star::linguistic2::XHyphenator > xHyph;
Link aOldLnk;
- LanguageType nLangError; // nicht vorhandene Sprache
- sal_uInt16 nPageCount; // Seitenanzahl fuer Progressanzeige
- sal_uInt16 nPageStart; // 1. gepruefte Seite
- sal_Bool bInSelection : 1; // Trennen von selektiertem Text
- sal_Bool bShowError : 1; // nicht vorhandene Sprache melden
- sal_Bool bAutomatic : 1; // Trennstellen ohne Rueckfrage einfuegen
+ LanguageType nLangError; // non existing language
+ sal_uInt16 nPageCount; // page count for progress view
+ sal_uInt16 nPageStart; // 1st checked page
+ sal_Bool bInSelection : 1; // seperating selected text
+ sal_Bool bShowError : 1; // report non existing language
+ sal_Bool bAutomatic : 1; // insert seperators without further inquiry
sal_Bool bInfoBox : 1; // display info-box when ending
DECL_LINK( SpellError, LanguageType * );
@@ -55,7 +55,7 @@ protected:
virtual sal_Bool SpellContinue();
virtual void SpellEnd( );
virtual sal_Bool SpellMore();
- virtual void InsertHyphen( const sal_uInt16 nPos ); // Hyphen einfuegen
+ virtual void InsertHyphen( const sal_uInt16 nPos ); // insert hyphen
public:
SwHyphWrapper( SwView* pVw,
diff --git a/sw/source/ui/inc/initui.hxx b/sw/source/ui/inc/initui.hxx
index 6e4acd3..9ec0bb3 100644
--- a/sw/source/ui/inc/initui.hxx
+++ b/sw/source/ui/inc/initui.hxx
@@ -62,7 +62,7 @@ extern SvStringsDtor* pDBNameList;
extern SvStringsDtor* pAuthFieldNameList;
extern SvStringsDtor* pAuthFieldTypeList;
-// stellt die Textbausteinverwaltung zur Verfuegung
+// provides textblock management
class SwGlossaries;
SW_DLLPUBLIC SwGlossaries* GetGlossaries();
diff --git a/sw/source/ui/inc/inpdlg.hxx b/sw/source/ui/inc/inpdlg.hxx
index 29159a5..0fe511a 100644
--- a/sw/source/ui/inc/inpdlg.hxx
+++ b/sw/source/ui/inc/inpdlg.hxx
@@ -41,7 +41,7 @@ class SwField;
class SwWrtShell;
/*--------------------------------------------------------------------
- Beschreibung: Einfuegen Felder
+ Description: insert fields
--------------------------------------------------------------------*/
class SwFldInputDlg: public SvxStandardDialog
diff --git a/sw/source/ui/inc/inputwin.hxx b/sw/source/ui/inc/inputwin.hxx
index 05f1896..a43438c 100644
--- a/sw/source/ui/inc/inputwin.hxx
+++ b/sw/source/ui/inc/inputwin.hxx
@@ -69,8 +69,8 @@ friend class InputEdit;
String aAktTableName, sOldFml;
sal_Int32 m_nActionCount;
- sal_Bool bFirst : 1; //Initialisierungen beim ersten Aufruf
- sal_Bool bActive : 1; //fuer Hide/Show beim Dokumentwechsel
+ sal_Bool bFirst : 1; // initialisations at first call
+ sal_Bool bActive : 1; // for hide/show when switching documents
sal_Bool bIsTable : 1;
sal_Bool bDelSel : 1;
bool m_bDoesUndo : 1;
diff --git a/sw/source/ui/inc/insfnote.hxx b/sw/source/ui/inc/insfnote.hxx
index dc5fdd4..adf30f9 100644
--- a/sw/source/ui/inc/insfnote.hxx
+++ b/sw/source/ui/inc/insfnote.hxx
@@ -41,7 +41,7 @@ class SwInsFootNoteDlg: public SvxStandardDialog
{
SwWrtShell &rSh;
- //Alles fuer das/die Zeichen
+ // everything for the character(s)
String aFontName;
CharSet eCharSet;
char cExtChar;
@@ -53,7 +53,7 @@ class SwInsFootNoteDlg: public SvxStandardDialog
Edit aNumberCharEdit;
PushButton aNumberExtChar;
- //Alles fuer die Auswahl Fussnote/Endnote
+ // everything for the selection footnote/endnote
FixedLine aTypeFL;
RadioButton aFtnBtn;
RadioButton aEndNoteBtn;
diff --git a/sw/source/ui/inc/labimg.hxx b/sw/source/ui/inc/labimg.hxx
index c36538b..6dcc8c3 100644
--- a/sw/source/ui/inc/labimg.hxx
+++ b/sw/source/ui/inc/labimg.hxx
@@ -50,28 +50,28 @@ public:
virtual SfxPoolItem* Clone(SfxItemPool* = 0) const;
- rtl::OUString aLstMake; //Letzte Auswahl merken.
+ rtl::OUString aLstMake; // remember last selection
rtl::OUString aLstType;
- rtl::OUString sDBName; // Verwendete Datenbank
-
- rtl::OUString aWriting; // Aufschrift
- rtl::OUString aMake; // Etikettenmarke
- rtl::OUString aType; // Etikettentyp
- rtl::OUString aBin; // Druckerschacht
- sal_Int32 lHDist; // Horizontaler Abstand (Benutzer)
- sal_Int32 lVDist; // Vertikaler Abstand (Benutzer)
- sal_Int32 lWidth; // Breite (Benutzer)
- sal_Int32 lHeight; // Hoehe (Benutzer)
- sal_Int32 lLeft; // Rand links (Benutzer)
- sal_Int32 lUpper; // Rand oben (Benutzer)
- sal_Int32 nCols; // Anzahl Spalten (Benutzer)
- sal_Int32 nRows; // Anzahl Zeilen (Benutzer)
- sal_Int32 nCol; // Spalte fuer Einzeldruck
- sal_Int32 nRow; // Zeile fuer Einzeldruck
- sal_Bool bAddr;// Adresse als Aufschrift?
- sal_Bool bCont;// Endlospapier?
- sal_Bool bPage;// Ganze Seite oder einzelnes Etikett?
- sal_Bool bSynchron;// Alle Etiketten synchronisieren
+ rtl::OUString sDBName; // used database
+
+ rtl::OUString aWriting; // label
+ rtl::OUString aMake; // label mark
+ rtl::OUString aType; // label type
+ rtl::OUString aBin; // printer shaft
+ sal_Int32 lHDist; // horizontal distance (user)
+ sal_Int32 lVDist; // vertical distance (user)
+ sal_Int32 lWidth; // width (user)
+ sal_Int32 lHeight; // height (user)
+ sal_Int32 lLeft; // left border (user)
+ sal_Int32 lUpper; // upper border (user)
+ sal_Int32 nCols; // number of columns (user)
+ sal_Int32 nRows; // number of rows (user)
+ sal_Int32 nCol; // column for single print
+ sal_Int32 nRow; // row for single print
+ sal_Bool bAddr;// adress as label?
+ sal_Bool bCont;// continuous paper?
+ sal_Bool bPage;// whole page or single labels?
+ sal_Bool bSynchron;// synchronise all labels
//parts of the business card
rtl::OUString aPrivFirstName;
diff --git a/sw/source/ui/inc/linenum.hxx b/sw/source/ui/inc/linenum.hxx
index a3a87aa..ba2ac59 100644
--- a/sw/source/ui/inc/linenum.hxx
+++ b/sw/source/ui/inc/linenum.hxx
@@ -42,7 +42,7 @@ class SwView;
class SwWrtShell;
/*--------------------------------------------------------------------
- Beschreibung: SingleTabDialog
+ Description: SingleTabDialog
--------------------------------------------------------------------*/
class SwLineNumberingDlg : public SfxSingleTabDialog
{
@@ -58,7 +58,7 @@ public:
};
/*--------------------------------------------------------------------
- Beschreibung: TabPage
+ Description: TabPage
--------------------------------------------------------------------*/
class SwLineNumberingPage : public SfxTabPage
{
diff --git a/sw/source/ui/inc/mailmergehelper.hxx b/sw/source/ui/inc/mailmergehelper.hxx
index dd7d5ea..35e1c8c 100644
--- a/sw/source/ui/inc/mailmergehelper.hxx
+++ b/sw/source/ui/inc/mailmergehelper.hxx
@@ -288,7 +288,7 @@ public:
SwMailMessage();
~SwMailMessage();
- // Attributes
+ // attributes
virtual ::rtl::OUString SAL_CALL getSenderName() throw (::com::sun::star::uno::RuntimeException);
virtual ::rtl::OUString SAL_CALL getSenderAddress() throw (::com::sun::star::uno::RuntimeException);
virtual ::rtl::OUString SAL_CALL getReplyToAddress() throw (::com::sun::star::uno::RuntimeException);
@@ -302,7 +302,7 @@ public:
virtual void SAL_CALL setBody( const ::com::sun::star::uno::Reference< ::com::sun::star::datatransfer::XTransferable >& _body )
throw (::com::sun::star::uno::RuntimeException);
- // Methods
+ // methods
virtual void SAL_CALL addRecipient( const ::rtl::OUString& sRecipientAddress ) throw (::com::sun::star::uno::RuntimeException);
virtual void SAL_CALL addCcRecipient( const ::rtl::OUString& sRecipientAddress ) throw (::com::sun::star::uno::RuntimeException);
virtual void SAL_CALL addBccRecipient( const ::rtl::OUString& sRecipientAddress ) throw (::com::sun::star::uno::RuntimeException);
diff --git a/sw/source/ui/inc/multmrk.hxx b/sw/source/ui/inc/multmrk.hxx
index 79413fe..efae555 100644
--- a/sw/source/ui/inc/multmrk.hxx
+++ b/sw/source/ui/inc/multmrk.hxx
@@ -39,7 +39,7 @@
class SwTOXMgr;
/*--------------------------------------------------------------------
- Beschreibung: Markierung fuer Verzeichniseintrag einfuegen
+ Description: insert mark for index entry
--------------------------------------------------------------------*/
class SwMultiTOXMarkDlg : public SvxStandardDialog
diff --git a/sw/source/ui/inc/navicfg.hxx b/sw/source/ui/inc/navicfg.hxx
index 8306ea4..d5a0db5 100644
--- a/sw/source/ui/inc/navicfg.hxx
+++ b/sw/source/ui/inc/navicfg.hxx
@@ -38,7 +38,7 @@ class SwNavigationConfig : public utl::ConfigItem
sal_Int32 nRegionMode; //InsertMode
sal_Int32 nActiveBlock; //ActiveBlock//Expand/CollapsState
sal_Bool bIsSmall; //ShowListBox
- sal_Bool bIsGlobalActive; //GlobalDocMode// Globalansicht fuer GlobalDoc gueltig?
+ sal_Bool bIsGlobalActive; //GlobalDocMode// global view for GlobalDoc valid?
com::sun::star::uno::Sequence<rtl::OUString> GetPropertyNames();
diff --git a/sw/source/ui/inc/navicont.hxx b/sw/source/ui/inc/navicont.hxx
index f0df6c3..9b4b96f 100644
--- a/sw/source/ui/inc/navicont.hxx
+++ b/sw/source/ui/inc/navicont.hxx
@@ -35,16 +35,16 @@ class SwDocShell;
class TransferDataContainer;
class TransferableDataHelper;
-/* [Beschreibung]
- Navigator-Bookmark zur eindeutigen Identifizierung im Sw
+/*
+ navigator bookmark for distinct identification in Sw
*/
class NaviContentBookmark
{
- String aUrl; // URL inkl. Sprungmarke
- String aDescr; // Description
- long nDocSh; // Adresse der DocShell
- sal_uInt16 nDefDrag; // Description enthaelt defaultDragType
+ String aUrl; // URL including jump mark
+ String aDescr; // description
+ long nDocSh; // adress of DocShell
+ sal_uInt16 nDefDrag; // description contains defaultDragType
public:
NaviContentBookmark();
diff --git a/sw/source/ui/inc/navipi.hxx b/sw/source/ui/inc/navipi.hxx
index d29ed81..110775f 100644
--- a/sw/source/ui/inc/navipi.hxx
+++ b/sw/source/ui/inc/navipi.hxx
@@ -77,7 +77,7 @@ class SwNavigationPI : public Window,
String sContentFileName;
String aContextArr[3];
String aStatusArr[4];
- Point aBoxBottomLeft; // Pos., wenn Box unten ist
+ Point aBoxBottomLeft; // Pos when Box is at bottom
SfxObjectShellLock *pxObjectShell;
SwView *pContentView;
@@ -95,7 +95,7 @@ class SwNavigationPI : public Window,
long nDocLBIniHeight;
long nWishWidth;
sal_uInt16 nAutoMarkIdx;
- sal_uInt16 nRegionMode; // 0 - URL, 1 - Bereich mit Link 2 - B. ohne Link
+ sal_uInt16 nRegionMode; // 0 - URL, 1 - region with link 2 - region without link
short nZoomIn;
short nZoomOutInit;
short nZoomOut;
@@ -143,7 +143,7 @@ protected:
virtual void DataChanged( const DataChangedEvent& rDCEvt );
- // zum App-Ende rechtzeitig ObjectShellLock loslassen
+ // release ObjectShellLock early enough for app end
virtual void Notify( SfxBroadcaster& rBC, const SfxHint& rHint );
NumEditAction& GetPageEdit();
@@ -155,7 +155,7 @@ public:
SwNavigationPI(SfxBindings*, SfxChildWindowContext*, Window*);
~SwNavigationPI();
- void GotoPage(); // Seite anspringen; bindbare Funktion
+ void GotoPage(); // jump to page; bindable function
void Update() { FillBox(); }
void UpdateListBox();
diff --git a/sw/source/ui/inc/num.hxx b/sw/source/ui/inc/num.hxx
index 287b8d3..f0bb1a6 100644
--- a/sw/source/ui/inc/num.hxx
+++ b/sw/source/ui/inc/num.hxx
@@ -101,7 +101,7 @@ class SwNumPositionTabPage : public SfxTabPage
sal_Bool bModified : 1;
sal_Bool bPreset : 1;
- sal_Bool bInInintControl : 1; //Modify-Fehler umgehen, soll ab 391 behoben sein
+ sal_Bool bInInintControl : 1; // work around modify-error; should be resolved from 391 on
bool bLabelAlignmentPosAndSpaceModeActive;
void InitControls();
diff --git a/sw/source/ui/inc/numpara.hxx b/sw/source/ui/inc/numpara.hxx
index 8bde96e..d631a0b 100644
--- a/sw/source/ui/inc/numpara.hxx
+++ b/sw/source/ui/inc/numpara.hxx
@@ -37,8 +37,8 @@
/* --- class SwParagraphNumTabPage ----------------------------------------
- Mit dieser TabPage werden Numerierungseinstellungen am Absatz bzw. der
- Absatzvorlage vorgenommen.
+ with this TabPage numbering settings at the paragraph / paragraph style
+ are performed.
---------------------------------------------------------------------------*/
class SwParagraphNumTabPage : public SfxTabPage
diff --git a/sw/source/ui/inc/optpage.hxx b/sw/source/ui/inc/optpage.hxx
index dcdd067..7f90b5a 100644
--- a/sw/source/ui/inc/optpage.hxx
+++ b/sw/source/ui/inc/optpage.hxx
@@ -95,7 +95,7 @@ public:
};
/*--------------------------------------------------------
- TabPage Druckereinstellungen Zusaetze
+ TabPage printer settings additions
--------------------------------------------------------- */
class SwAddPrinterTabPage : public SfxTabPage
{
@@ -199,7 +199,7 @@ class SwStdFontTabPage : public SfxTabPage
SwStdFontConfig* pFontConfig;
SwWrtShell* pWrtShell;
LanguageType eLanguage;
- // waren nur defaults vorhanden? wurden sie mit den Boxen ueberschrieben
+ // only defaults were there? they were signed with the boxes
sal_Bool bListDefault :1;
sal_Bool bSetListDefault :1;
sal_Bool bLabelDefault :1;
@@ -301,7 +301,7 @@ public:
};
/*--------------------------------------------------
- TabPage fuer ShadowCrsr
+ TabPage for ShadowCrsr
--------------------------------------------------*/
class SwShdwCrsrOptionsTabPage : public SfxTabPage
{
@@ -352,7 +352,7 @@ public:
};
/*-----------------------------------------------------------------------
- Beschreibung: Markierungsvorschau
+ Description: mark preview
-----------------------------------------------------------------------*/
class SwMarkPreview : public Window
{
@@ -389,7 +389,7 @@ public:
};
/*-----------------------------------------------------------------------
- Beschreibung: Redlining-Optionen
+ Description: redlining options
-----------------------------------------------------------------------*/
class SwRedlineOptionsTabPage : public SfxTabPage
{
@@ -445,7 +445,7 @@ public:
};
/*-------------------------------------------------------
- TabPage Testeinstellungen fuer SW
+ TabPage test settings for SW
--------------------------------------------------------- */
#if OSL_DEBUG_LEVEL > 1
@@ -484,4 +484,4 @@ private:
#endif //PRODUCT
#endif
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
\ No newline at end of file
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/sw/source/ui/inc/outline.hxx b/sw/source/ui/inc/outline.hxx
index 7c8e37b..083921f 100644
--- a/sw/source/ui/inc/outline.hxx
+++ b/sw/source/ui/inc/outline.hxx
@@ -44,7 +44,7 @@
#include <vcl/field.hxx>
-#include "swtypes.hxx" //fuer MAXLEVEL
+#include "swtypes.hxx" //for MAXLEVEL
#include <numprevw.hxx>
#include <numberingtypelistbox.hxx>
diff --git a/sw/source/ui/inc/pgfnote.hxx b/sw/source/ui/inc/pgfnote.hxx
index 30efd28..d9e92e4 100644
--- a/sw/source/ui/inc/pgfnote.hxx
+++ b/sw/source/ui/inc/pgfnote.hxx
@@ -38,7 +38,7 @@
#include <svtools/ctrlbox.hxx>
/*--------------------------------------------------------------------
- Beschreibung: Fussnoteneinstellungs-TabPage
+ Description: footnote settings TabPage
--------------------------------------------------------------------*/
class SwFootNotePage: public SfxTabPage
{
diff --git a/sw/source/ui/inc/popbox.hxx b/sw/source/ui/inc/popbox.hxx
index 198159a..41595dc 100644
--- a/sw/source/ui/inc/popbox.hxx
+++ b/sw/source/ui/inc/popbox.hxx
@@ -37,7 +37,7 @@ class SwNavigationPI;
class SwHelpToolBox: public ToolBox, public DropTargetHelper
{
Link aDoubleClickLink;
- Link aRightClickLink; // Link bekommt MouseEvent als Parameter !!!
+ Link aRightClickLink; // link gets mouse event as parameter !!!
using ToolBox::DoubleClick;
diff --git a/sw/source/ui/inc/prcntfld.hxx b/sw/source/ui/inc/prcntfld.hxx
index da7de46..0ec702a 100644
--- a/sw/source/ui/inc/prcntfld.hxx
+++ b/sw/source/ui/inc/prcntfld.hxx
@@ -33,7 +33,7 @@
class SW_DLLPUBLIC PercentField : public MetricField
{
- sal_Int64 nRefValue; // 100%-Wert fuer Umrechnung (in Twips)
+ sal_Int64 nRefValue; // 100% value for conversion (in Twips)
sal_Int64 nOldMax;
sal_Int64 nOldMin;
sal_Int64 nOldSpinSize;
diff --git a/sw/source/ui/inc/pview.hxx b/sw/source/ui/inc/pview.hxx
index 875579c..92dba1e 100644
--- a/sw/source/ui/inc/pview.hxx
+++ b/sw/source/ui/inc/pview.hxx
@@ -74,7 +74,7 @@ public:
SwPagePreViewWin( Window* pParent, SwPagePreView& rView );
~SwPagePreViewWin();
- //Ruft ViewShell::Paint
+ // calls ViewShell::Paint
virtual void Paint( const Rectangle& rRect );
virtual void KeyInput( const KeyEvent & );
virtual void Command( const CommandEvent& rCEvt );
@@ -172,12 +172,12 @@ public:
};
/*--------------------------------------------------------------------
- Beschreibung: Sicht auf ein Dokument
+ Description: view of a document
--------------------------------------------------------------------*/
class SW_DLLPUBLIC SwPagePreView: public SfxViewShell
{
- // ViewWindow und Henkel zur Core
- // aktuelle Dispatcher-Shell
+ // ViewWindow and handle to core
+ // current dispatcher shell
SwPagePreViewWin aViewWin;
//viewdata of the previous SwView and the new crsrposition
String sSwViewData,
@@ -185,18 +185,17 @@ class SW_DLLPUBLIC SwPagePreView: public SfxViewShell
sNewCrsrPos;
// to support keyboard the number of the page to go to can be set too
sal_uInt16 nNewPage;
- // Sichtbarer Bereich
+ // visible range
String sPageStr;
Size aDocSz;
Rectangle aVisArea;
- // MDI Bedienelemente
+ // MDI control elements
SwScrollbar *pHScrollbar;
SwScrollbar *pVScrollbar;
ImageButton *pPageUpBtn,
*pPageDownBtn;
- // Dummy-Window zum F�llen der rechten unteren Ecke, wenn beide Scrollbars
- // aktiv sind
+ // dummy window for filling the lower right edge when both scrollbars are active
Window *pScrollFill;
sal_uInt16 mnPageCount;
@@ -284,7 +283,7 @@ public:
sal_uInt16 GetNewPage() const {return nNewPage;}
void SetNewPage(sal_uInt16 nSet) {nNewPage = nSet;}
- // Handler
+ // handler
void Execute(SfxRequest&);
void GetState(SfxItemSet&);
void StateUndo(SfxItemSet&);
@@ -324,7 +323,7 @@ public:
~SwPagePreView();
};
-// ----------------- inline Methoden ----------------------
+// ----------------- inline methods ----------------------
inline void SwPagePreView::AdjustEditWin()
{
OuterResizePixel( Point(), GetFrameWindow()->GetOutputSizePixel() );
diff --git a/sw/source/ui/inc/redlndlg.hxx b/sw/source/ui/inc/redlndlg.hxx
index 714d52f..bb42ab1 100644
--- a/sw/source/ui/inc/redlndlg.hxx
+++ b/sw/source/ui/inc/redlndlg.hxx
@@ -44,17 +44,17 @@ class SwChildWinWrapper;
struct SwRedlineDataChild
{
- const SwRedlineData* pChild; // Verweis auf originale gestackte Daten
- const SwRedlineDataChild* pNext; // Verweis auf gestackte Daten
- SvLBoxEntry* pTLBChild; // zugehoeriger TreeListBox-Eintrag
+ const SwRedlineData* pChild; // link to original stacked data
+ const SwRedlineDataChild* pNext; // link to stacked data
+ SvLBoxEntry* pTLBChild; // corresponding TreeListBox entry
};
struct SwRedlineDataParent
{
const SwRedlineData* pData; // RedlineDataPtr
- const SwRedlineDataChild* pNext; // Verweis auf gestackte Daten
- SvLBoxEntry* pTLBParent; // zugehoeriger TreeListBox-Eintrag
- String sComment; // Redline-Kommentar
+ const SwRedlineDataChild* pNext; // link to stacked data
+ SvLBoxEntry* pTLBParent; // corresponding TreeListBox entry
+ String sComment; // redline comment
inline sal_Bool operator==( const SwRedlineDataParent& rObj ) const
{ return (pData && pData->GetSeqNo() == rObj.pData->GetSeqNo()); }
diff --git a/sw/source/ui/inc/regionsw.hxx b/sw/source/ui/inc/regionsw.hxx
index 8133e18..d9d8246 100644
--- a/sw/source/ui/inc/regionsw.hxx
+++ b/sw/source/ui/inc/regionsw.hxx
@@ -62,7 +62,7 @@ namespace sfx2
}
/*************************************************************************
- Dialog "Bereiche bearbeiten"
+ dialog "edit regions"
*************************************************************************/
class SectRepr;
typedef SectRepr* SectReprPtr;
@@ -156,7 +156,7 @@ public:
};
/*************************************************************************
- Dialog "Bereich einfuegen"
+ dialog "insert region"
*************************************************************************/
class SwInsertSectionTabPage : public SfxTabPage
{
diff --git a/sw/source/ui/inc/scroll.hxx b/sw/source/ui/inc/scroll.hxx
index 4f88841..c99ecaa 100644
--- a/sw/source/ui/inc/scroll.hxx
+++ b/sw/source/ui/inc/scroll.hxx
@@ -32,11 +32,11 @@
class SwScrollbar: public ScrollBar
{
Size aDocSz;
- sal_Bool bHori :1; // Horizontal = sal_True, sonst Vertikal
- sal_Bool bAuto :1; // fuer Scrollingmode
+ sal_Bool bHori :1; // horizontal = salTrue, otherwise vertical
+ sal_Bool bAuto :1; // for scrolling mode
sal_Bool bThumbEnabled:1;
- sal_Bool bVisible :1; // Show/Hide sollen nur noch dieses Flag setzen
- sal_Bool bSizeSet :1; // wurde die Groesse bereits gesetzt?
+ sal_Bool bVisible :1; // show/hide should only set this flag
+ sal_Bool bSizeSet :1; // was the size already set?
void AutoShow();
@@ -51,11 +51,11 @@ public:
void SetPosSizePixel( const Point& rNewPos, const Size& rNewSize );
sal_Bool IsVisible(sal_Bool bReal) const { return bReal ? ScrollBar::IsVisible() : bVisible; }
- // Aenderung der Dokumentgroesse
+ // changing of document size
void DocSzChgd(const Size &rNewSize);
- // Aenderung des sichtbaren Bereiches
+ // changing of visible region
void ViewPortChgd(const Rectangle &rRectangle);
- // was fuer einer ist es denn ??
+ // what is it??
sal_Bool IsHoriScroll() const { return bHori; }
void SetAuto(sal_Bool bSet);
commit d5f651cf909f6fa0a1426eff382051cd93a131d0
Author: Martin Kepplinger <martinkepplinger at eml.cc>
Date: Thu Apr 21 16:51:03 2011 +0200
Translate german code comments
Translate some german code comments to english!
This is contributed under the terms of the MPL 1.1 / GPLv3+ / LGPLv3+ triple
license.
diff --git a/sw/source/ui/inc/colmgr.hxx b/sw/source/ui/inc/colmgr.hxx
index 3712aa1..7ded3b5 100644
--- a/sw/source/ui/inc/colmgr.hxx
+++ b/sw/source/ui/inc/colmgr.hxx
@@ -36,8 +36,7 @@ SW_DLLPUBLIC void FitToActualSize(SwFmtCol& rCol, sal_uInt16 nWidth);
class SW_DLLPUBLIC SwColMgr
{
public:
- // lActWidth wird aus den Edits des Seitendialogs
- // direkt uebergeben
+ // lActWidth is passed directly from the page dialogs edits
SwColMgr(const SfxItemSet &rSet, sal_uInt16 nActWidth = USHRT_MAX);
~SwColMgr();
@@ -82,7 +81,7 @@ private:
sal_uInt16 nWidth;
};
-// INLINE METHODE --------------------------------------------------------
+// INLINE METHOD --------------------------------------------------------
inline sal_uInt16 SwColMgr::GetCount() const
{
return aFmtCol.GetNumCols();
diff --git a/sw/source/ui/inc/column.hxx b/sw/source/ui/inc/column.hxx
index 865e55c..d992060 100644
--- a/sw/source/ui/inc/column.hxx
+++ b/sw/source/ui/inc/column.hxx
@@ -99,7 +99,7 @@ class ColumnValueSet : public ValueSet
};
/*--------------------------------------------------------------------
- Beschreibung: Spaltendialog jetzt als TabPage
+ Description: column dialog now as TabPage
--------------------------------------------------------------------*/
class SwColumnPage : public SfxTabPage
{
diff --git a/sw/source/ui/inc/conarc.hxx b/sw/source/ui/inc/conarc.hxx
index 56204a2..3e2779e 100644
--- a/sw/source/ui/inc/conarc.hxx
+++ b/sw/source/ui/inc/conarc.hxx
@@ -32,7 +32,7 @@
/*************************************************************************
|*
-|* Rechteck zeichnen
+|* draw rectangle
|*
\************************************************************************/
@@ -48,7 +48,7 @@ public:
virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
- virtual void Activate(const sal_uInt16 nSlotId); // Funktion aktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // activate function
virtual void Deactivate();
};
diff --git a/sw/source/ui/inc/concustomshape.hxx b/sw/source/ui/inc/concustomshape.hxx
index e2dd43b..254f670 100644
--- a/sw/source/ui/inc/concustomshape.hxx
+++ b/sw/source/ui/inc/concustomshape.hxx
@@ -37,7 +37,7 @@ class SfxRequest;
/*************************************************************************
|*
-|* Rechteck zeichnen
+|* draw rectangle
|*
\************************************************************************/
@@ -56,7 +56,7 @@ class ConstCustomShape : public SwDrawBase
virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
- virtual void Activate(const sal_uInt16 nSlotId); // Function aktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // activate function
rtl::OUString GetShapeType() const;
static rtl::OUString GetShapeTypeFromRequest( SfxRequest& rReq );
diff --git a/sw/source/ui/inc/conform.hxx b/sw/source/ui/inc/conform.hxx
index 28914d6..e7750d8 100644
--- a/sw/source/ui/inc/conform.hxx
+++ b/sw/source/ui/inc/conform.hxx
@@ -38,7 +38,7 @@ public:
// Mouse- & Key-Events
virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
- virtual void Activate(const sal_uInt16 nSlotId); // Function aktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // activate function
virtual void CreateDefaultObject();
};
diff --git a/sw/source/ui/inc/conpoly.hxx b/sw/source/ui/inc/conpoly.hxx
index bcfb77e..a765d4f 100644
--- a/sw/source/ui/inc/conpoly.hxx
+++ b/sw/source/ui/inc/conpoly.hxx
@@ -32,7 +32,7 @@
/*************************************************************************
|*
-|* Basisklasse fuer alle Funktionen
+|* base class for all functions
|*
\************************************************************************/
@@ -48,7 +48,7 @@ public:
virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
- virtual void Activate(const sal_uInt16 nSlotId); // Function aktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // activate function
};
diff --git a/sw/source/ui/inc/conrect.hxx b/sw/source/ui/inc/conrect.hxx
index a5ef397..5152bd2 100644
--- a/sw/source/ui/inc/conrect.hxx
+++ b/sw/source/ui/inc/conrect.hxx
@@ -33,7 +33,7 @@
/*************************************************************************
|*
-|* Rechteck zeichnen
+|* draw rectangle
|*
\************************************************************************/
@@ -52,7 +52,7 @@ class ConstRectangle : public SwDrawBase
virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
virtual sal_Bool MouseButtonDown(const MouseEvent& rMEvt);
- virtual void Activate(const sal_uInt16 nSlotId); // Function aktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // activate function
};
diff --git a/sw/source/ui/inc/content.hxx b/sw/source/ui/inc/content.hxx
index 5c75666..60f9150 100644
--- a/sw/source/ui/inc/content.hxx
+++ b/sw/source/ui/inc/content.hxx
@@ -41,7 +41,7 @@ class SwTOXBase;
class SwRedline;
//----------------------------------------------------------------------------
-// Hilfsklassen
+// helper classes
//----------------------------------------------------------------------------
class SwPopup : public PopupMenu
@@ -169,29 +169,28 @@ public:
const SwTOXBase* GetTOXBase() const {return pBase;}
};
/*
- class ContentType enthaelt Informationen zu einer Inhaltsform
- Das MemberArray wird nur gefuellt, wenn der Inhalt mit GetMember
- angefordert wird. Es wird nach Invalidate() nur dann neu geladen,
- wenn der Inhalt erneut ausgelesen werden soll.
+ class ContentType contains information to one type of content.
+ MemberArray is only populated if the content is requested by
+ GetMember. It is reloaded after Invalidate() only if the content
+ should be read again.
*/
//----------------------------------------------------------------------------
-//----------------------------------------------------------------------------
class SwContentType : public SwTypeNumber
{
SwWrtShell* pWrtShell;
- SwContentArr* pMember; // Array fuer Inhalte
- String sContentTypeName; // Name der Inhaltsform
- String sSingleContentTypeName; // Name der Inhaltsform, Singular
- String sTypeToken; // Anhaengsel fuer URL
- sal_uInt16 nMemberCount; // Inhaltsanzahl
- sal_uInt16 nContentType; // Id der Inhaltsform
+ SwContentArr* pMember; // array for content
+ String sContentTypeName; // name of content type
+ String sSingleContentTypeName; // name of content type, singular
+ String sTypeToken; // attachment for URL
+ sal_uInt16 nMemberCount; // content count
+ sal_uInt16 nContentType; // content type's Id
sal_uInt8 nOutlineLevel;
- sal_Bool bMemberFilled : 1; // wurden die Inhalte bereits eingefuegt?
- sal_Bool bIsInternalDrag:1; // koennen die Inhalte verschoben werden?
+ sal_Bool bMemberFilled : 1; // has content already been inserted?
+ sal_Bool bIsInternalDrag:1; // can content be relocated?
sal_Bool bDataValid : 1; //
- sal_Bool bEdit: 1; // kann diese Type bearbeitet werden ?
- sal_Bool bDelete: 1; // kann diese Type geloescht werden ?
+ sal_Bool bEdit: 1; // can this type be edited?
+ sal_Bool bDelete: 1; // can this type be deleted?
protected:
void RemoveNewline(String&);
public:
@@ -214,7 +213,7 @@ public:
Invalidate();
}
- void Invalidate(); // nur nMemberCount wird neu gelesen
+ void Invalidate(); // only nMemberCount is read again
sal_Bool IsEditable() const {return bEdit;}
sal_Bool IsDeletable() const {return bDelete;}
diff --git a/sw/source/ui/inc/conttree.hxx b/sw/source/ui/inc/conttree.hxx
index f6e8468..899f7d6 100644
--- a/sw/source/ui/inc/conttree.hxx
+++ b/sw/source/ui/inc/conttree.hxx
@@ -73,8 +73,8 @@ class SwContentTree : public SvTreeListBox
String sPostItHide;
String sPostItDelete;
- SwWrtShell* pHiddenShell; // gedropptes Doc
- SwWrtShell* pActiveShell; // die aktive oder eine konst. offene View
+ SwWrtShell* pHiddenShell; // dropped Doc
+ SwWrtShell* pActiveShell; // the active or a const. open view
SwNavigationConfig* pConfig;
std::map< void*, sal_Bool > mOutLineNodeMap;
@@ -207,7 +207,7 @@ public:
//----------------------------------------------------------------------------
-// TreeListBox fuer Globaldokumente
+// TreeListBox for global documents
//----------------------------------------------------------------------------
class SwLBoxString : public SvLBoxString
@@ -235,9 +235,9 @@ private:
ImageList aEntryImages;
SwWrtShell* pActiveShell; //
- SvLBoxEntry* pEmphasisEntry; // Drag'n Drop-Emphasis
- SvLBoxEntry* pDDSource; // Quelle beim DnD
- SwGlblDocContents* pSwGlblDocContents; // Array mit sortierten Inhalten
+ SvLBoxEntry* pEmphasisEntry; // Drag'n Drop emphasis
+ SvLBoxEntry* pDDSource; // source for Drag'n Drop
+ SwGlblDocContents* pSwGlblDocContents; // array with sorted content
Window* pDefParentWin;
SwGlblDocContent* pDocContent;
diff --git a/sw/source/ui/inc/cption.hxx b/sw/source/ui/inc/cption.hxx
index b6fe3e7..f23f4be 100644
--- a/sw/source/ui/inc/cption.hxx
+++ b/sw/source/ui/inc/cption.hxx
@@ -95,8 +95,8 @@ class SwCaptionDialog : public SvxStandardDialog
SwCaptionPreview aPrevWin;
- SwView &rView; //Suchen per aktive ::com::sun::star::sdbcx::View vermeiden.
- SwFldMgr *pMgr; //Ptr um das include zu sparen
+ SwView &rView; // search per active, avoid ::com::sun::star::sdbcx::View
+ SwFldMgr *pMgr; // pointer to save the include
SelectionType eType;
String sCharacterStyle;
diff --git a/sw/source/ui/inc/dbinsdlg.hxx b/sw/source/ui/inc/dbinsdlg.hxx
index e299bff..89a5948 100644
--- a/sw/source/ui/inc/dbinsdlg.hxx
+++ b/sw/source/ui/inc/dbinsdlg.hxx
@@ -160,7 +160,7 @@ class SwInsertDBColAutoPilot : public SfxModalDialog, public utl::ConfigItem
virtual void Commit();
void Load();
- // setze die Tabellen - Eigenschaften
+ // set the tables - properties
void SetTabSet();
public:
diff --git a/sw/source/ui/inc/docstdlg.hxx b/sw/source/ui/inc/docstdlg.hxx
index ee4fc41..233f7d2 100644
--- a/sw/source/ui/inc/docstdlg.hxx
+++ b/sw/source/ui/inc/docstdlg.hxx
@@ -36,7 +36,7 @@
#include "docstat.hxx"
/*--------------------------------------------------------------------
- Beschreibung: DocInfo jetzt als Page
+ Description: DocInfo now as page
--------------------------------------------------------------------*/
class SwDocStatPage: public SfxTabPage
{
diff --git a/sw/source/ui/inc/drawbase.hxx b/sw/source/ui/inc/drawbase.hxx
index 47f7a2d..24430ca 100644
--- a/sw/source/ui/inc/drawbase.hxx
+++ b/sw/source/ui/inc/drawbase.hxx
@@ -40,7 +40,7 @@ class MouseEvent;
/*************************************************************************
|*
-|* Basisklasse fuer alle Funktionen
+|* base class for all functions
|*
\************************************************************************/
@@ -50,8 +50,8 @@ protected:
SwView* m_pView;
SwWrtShell* m_pSh;
SwEditWin* m_pWin;
- Point m_aStartPos; // Position von BeginCreate
- Point m_aMDPos; // Position von MouseButtonDown
+ Point m_aStartPos; // position of BeginCreate
+ Point m_aMDPos; // position of MouseButtonDown
sal_uInt16 m_nSlotId;
sal_Bool m_bCreateObj :1;
sal_Bool m_bInsForm :1;
@@ -66,7 +66,7 @@ public:
inline sal_Bool IsInsertForm() const { return m_bInsForm; }
inline sal_Bool IsCreateObj() const { return m_bCreateObj; }
- // Mouse- & Key-Events; Returnwert=sal_True: Event wurde bearbeitet
+ // mouse- & key events; return value=sal_True: event was edited
virtual sal_Bool KeyInput(const KeyEvent& rKEvt);
virtual sal_Bool MouseMove(const MouseEvent& rMEvt);
virtual sal_Bool MouseButtonUp(const MouseEvent& rMEvt);
@@ -76,8 +76,8 @@ public:
void SetSlotId(sal_uInt16 nSlot) {m_nSlotId = nSlot;}
sal_uInt16 GetSlotId() { return m_nSlotId;}
- virtual void Activate(const sal_uInt16 nSlotId); // Function aktivieren
- virtual void Deactivate(); // Function deaktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // activate fuction
+ virtual void Deactivate(); // deactivate function
virtual void CreateDefaultObject();
diff --git a/sw/source/ui/inc/dselect.hxx b/sw/source/ui/inc/dselect.hxx
index 165ae46..fa6e036 100644
--- a/sw/source/ui/inc/dselect.hxx
+++ b/sw/source/ui/inc/dselect.hxx
@@ -32,7 +32,7 @@
/*************************************************************************
|*
-|* Rechteck zeichnen
+|* draw rectangle
|*
\************************************************************************/
@@ -41,10 +41,10 @@ class DrawSelection : public SwDrawBase
public:
DrawSelection(SwWrtShell* pSh, SwEditWin* pWin, SwView* pView);
- // Mouse- & Key-Events
+ // mouse- & key events
virtual sal_Bool KeyInput(const KeyEvent& rKEvt);
- virtual void Activate(const sal_uInt16 nSlotId); // Function aktivieren
+ virtual void Activate(const sal_uInt16 nSlotId); // activate function
};
diff --git a/sw/source/ui/inc/edtwin.hxx b/sw/source/ui/inc/edtwin.hxx
index 3db9f7c..3cb83fa 100644
--- a/sw/source/ui/inc/edtwin.hxx
+++ b/sw/source/ui/inc/edtwin.hxx
@@ -54,7 +54,7 @@ struct QuickHelpData;
class SdrDropMarkerOverlay;
/*--------------------------------------------------------------------
- Beschreibung: Eingabe-Fenster
+ Description: input window
--------------------------------------------------------------------*/
class SwEditWin: public Window,
@@ -76,18 +76,18 @@ friend void PageNumNotify( ViewShell* pVwSh,
static sal_Bool bReplaceQuote;
static long nDDStartPosX, nDDStartPosY;
- static Color aTextColor; //Textfarbe, fuer die Giesskanne
- static sal_Bool bTransparentBackColor; // Hintergrund transparent
- static Color aTextBackColor; //Texthintergrundfarbe, fuer die Giesskanne
+ static Color aTextColor; // text color; for the watering can
+ static sal_Bool bTransparentBackColor; // transparent background
+ static Color aTextBackColor; // text background; for the watering can
/*
- * Timer und Handler fuer das Weiterscrollen, wenn der
- * Mauspointer innerhalb eines Drag-Vorgangs ausserhalb des
- * EditWin stehen bleibt. In regelmaessigen Intervallen wird
- * die Selektion in Richtung der Mausposition vergroessert.
+ * timer and handler for scrolling on when the mousepointer
+ * stopps outside of EditWin during a drag-operation.
+ * The selection is increased towards the mouse position
+ * regularly.
*/
AutoTimer aTimer;
- // Timer fuer verschachtelte KeyInputs (z.B. fuer Tabellen)
+ // timer for overlapping KeyInputs (e.g. for tables)
Timer aKeyInputTimer;
// timer for ANY-KeyInut question without a following KeyInputEvent
Timer aKeyInputFlushTimer;
@@ -99,11 +99,11 @@ friend void PageNumNotify( ViewShell* pVwSh,
Point aRszMvHdlPt;
Timer aTemplateTimer;
- // Type/Objecte ueber dem der MousePointer steht
+ // type/object where the mouse pointer is
SwCallMouseEvent aSaveCallEvent;
SwApplyTemplate *pApplyTempl;
- SwAnchorMarker *pAnchorMarker; // zum Verschieben eines Ankers
+ SwAnchorMarker *pAnchorMarker; // for relocating the anchor
SdrDropMarkerOverlay *pUserMarker;
SdrObject *pUserMarkerObj;
@@ -112,29 +112,29 @@ friend void PageNumNotify( ViewShell* pVwSh,
SwView &rView;
- int aActHitType; // aktueller Mauspointer
+ int aActHitType; // current mouse pointer
- sal_uLong m_nDropFormat; //Format aus dem letzten QueryDrop
- sal_uInt16 m_nDropAction; //Action aus dem letzten QueryDrop
- sal_uInt16 m_nDropDestination; //Ziel aus dem letzten QueryDrop
+ sal_uLong m_nDropFormat; // format from the last QueryDrop
+ sal_uInt16 m_nDropAction; // action from the last QueryDrop
+ sal_uInt16 m_nDropDestination; // destination from the last QueryDrop
sal_uInt16 eBezierMode;
- sal_uInt16 nInsFrmColCount; //Spaltenzahl fuer interaktiven Rahmen
+ sal_uInt16 nInsFrmColCount; // column number for interactive frame
SdrObjKind eDrawMode;
sal_Bool bLinkRemoved : 1,
bMBPressed : 1,
bInsDraw : 1,
bInsFrm : 1,
bIsInMove : 1,
- bIsInDrag : 1, //StartExecuteDrag nich doppelt ausfuehren
- bOldIdle : 1, //Zum abschalten des Idle'ns
- bOldIdleSet : 1, //waehrend QeueryDrop
+ bIsInDrag : 1, // don't execute StartExecuteDrag twice
+ bOldIdle : 1, // to stop to idle
+ bOldIdleSet : 1, // during QeueryDrop
bTblInsDelMode : 1, //
bTblIsInsMode : 1, //
bTblIsColMode : 1, //
- bChainMode : 1, //Rahmen verbinden
- bWasShdwCrsr : 1, //ShadowCrsr war im MouseButtonDown an
- bLockInput : 1, //Lock waehrend die Rechenleiste aktiv ist
+ bChainMode : 1, // connect frames
+ bWasShdwCrsr : 1, // ShadowCrsr was on in MouseButtonDown
+ bLockInput : 1, // lock while calc panel is active
bIsRowDrag : 1, //selection of rows is used, in combination with pRowColumnSelectionStart
/** #i42732# display status of font size/name depending on either the input language or the
selection position depending on what has changed lately
@@ -158,7 +158,7 @@ friend void PageNumNotify( ViewShell* pVwSh,
sal_Bool EnterDrawMode(const MouseEvent& rMEvt, const Point& aDocPos);
sal_Bool RulerColumnDrag( const MouseEvent& rMEvt, sal_Bool bVerticalMode);
- //Hilfsfunktionen fuer D&D
+ // helper function for D&D
void DropCleanup();
void CleanupDropUserMarker();
sal_uInt16 GetDropDestination( const Point& rPixPnt,
@@ -167,10 +167,10 @@ friend void PageNumNotify( ViewShell* pVwSh,
sal_Bool SelectMenuPosition(SwWrtShell& rSh, const Point& rMousePos );
/*
- * Handler fuer das Weiterscrollen, wenn der Mauspointer innerhalb eines
- * Drag-Vorgangs ausserhalb des EditWin stehen bleibt. In regelmaessigen
- * Intervallen wird die Selektion in Richtung der Mausposition
- * vergroessert.
+ * handler for scrolling on when the mousepointer
+ * stopps outside of EditWin during a drag-operation.
+ * The selection is regularly increased towards the mouse
+ * position.
*/
DECL_LINK( TimerHandler, Timer * );
void StartDDTimer();
@@ -180,10 +180,10 @@ friend void PageNumNotify( ViewShell* pVwSh,
// timer for ANY-KeyInut question without a following KeyInputEvent
DECL_LINK( KeyInputFlushHandler, Timer * );
- // Timer fuer verschachtelte KeyInputs (z.B. fuer Tabellen)
+ // timer for overlapping KeyInputs (e.g. for tables)
DECL_LINK( KeyInputTimerHandler, Timer * );
- // Timer fuer das ApplyTemplates per Maus (verkapptes Drag&Drop)
+ // timer for ApplyTemplates via mouse (in disguise Drag&Drop)
DECL_LINK( TemplateTimerHdl, Timer* );
using OutputDevice::GetTextColor;
@@ -234,10 +234,10 @@ public:
sal_Bool IsFrmAction() { return (bInsFrm); }
inline sal_uInt16 GetBezierMode() { return eBezierMode; }
void SetBezierMode(sal_uInt16 eBezMode) { eBezierMode = eBezMode; }
- void EnterDrawTextMode(const Point& aDocPos); // DrawTextEditMode einschalten
+ void EnterDrawTextMode(const Point& aDocPos); // turn on DrawTextEditMode
void InsFrm(sal_uInt16 nCols);
void StopInsFrm();
- sal_uInt16 GetFrmColCount() const {return nInsFrmColCount;} //Spaltenzahl fuer interaktiven Rahmen
+ sal_uInt16 GetFrmColCount() const {return nInsFrmColCount;} // column number for interactive frame
void SetChainMode( sal_Bool bOn );
@@ -277,7 +277,7 @@ public:
virtual ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible > CreateAccessible();
- // Tipfenster loeschen
+ // delete tip window
static void ClearTip();
static inline long GetDDStartPosX() { return nDDStartPosX; }
diff --git a/sw/source/ui/inc/envimg.hxx b/sw/source/ui/inc/envimg.hxx
index 4b0ddc8..6eae7d9 100644
--- a/sw/source/ui/inc/envimg.hxx
+++ b/sw/source/ui/inc/envimg.hxx
@@ -51,19 +51,19 @@ class SW_DLLPUBLIC SwEnvItem : public SfxPoolItem
{
public:
- rtl::OUString aAddrText; // Text fuer Empfaenger
- sal_Bool bSend; // Absender?
- rtl::OUString aSendText; // Text fuer Absender
- sal_Int32 lAddrFromLeft; // Linker Abstand fuer Empfaenger (twips)
- sal_Int32 lAddrFromTop; // Oberer Abstand fuer Empfaenger (twips)
- sal_Int32 lSendFromLeft; // Linker Abstand fuer Absender (twips)
- sal_Int32 lSendFromTop; // Oberer Abstand fuer Absender (twips)
- sal_Int32 lWidth; // Breite des Umschlags (twips)
- sal_Int32 lHeight; // Hoehe des Umschlags (twips)
- SwEnvAlign eAlign; // Ausrichtung beim Einzug
- sal_Bool bPrintFromAbove; // Von oben drucken?
- sal_Int32 lShiftRight; // Verschiebung nach rechts (twips)
- sal_Int32 lShiftDown; // Verschiebung nach unten (twips)
+ rtl::OUString aAddrText; // text for reciever
+ sal_Bool bSend; // sender?
+ rtl::OUString aSendText; // text for sender
+ sal_Int32 lAddrFromLeft; // left gap for reciever (twips)
+ sal_Int32 lAddrFromTop; // upper gap for reciever (twips)
+ sal_Int32 lSendFromLeft; // left gap for sender (twips)
+ sal_Int32 lSendFromTop; // upper gap for sender (twips)
+ sal_Int32 lWidth; // envelope's width (twips)
+ sal_Int32 lHeight; // envelope's height (twips)
+ SwEnvAlign eAlign; // alignment at indent
+ sal_Bool bPrintFromAbove; // print from above?
+ sal_Int32 lShiftRight; // shift to right (twips)
+ sal_Int32 lShiftDown; // shift down (twips)
SwEnvItem();
SwEnvItem(const SwEnvItem& rItem);
diff --git a/sw/source/ui/inc/fldmgr.hxx b/sw/source/ui/inc/fldmgr.hxx
index 6689bfd..ca89df4 100644
--- a/sw/source/ui/inc/fldmgr.hxx
+++ b/sw/source/ui/inc/fldmgr.hxx
@@ -55,7 +55,7 @@ class SvNumberFormatter;
class Window;
/*--------------------------------------------------------------------
- Beschreibung: Die Gruppen von Feldern
+ Description: the groups of fields
--------------------------------------------------------------------*/
enum SwFldGroups
{
@@ -74,8 +74,8 @@ struct SwFldGroupRgn
};
/*--------------------------------------------------------------------
- Beschreibung: Der FeldManager handelt das Einfuegen von Felder
- ueber Command-Strings
+ Description: the field manager handles the insertation of fields
+ with command strings
--------------------------------------------------------------------*/
struct SwInsertFld_Data
{
@@ -117,7 +117,7 @@ private:
SwField* pCurFld;
SbModule* pModule;
const SvxMacroItem* pMacroItem;
- SwWrtShell* pWrtShell; // darf auch NULL sein!
+ SwWrtShell* pWrtShell; // can be ZERO too!
String aCurPar1;
String aCurPar2;
String sCurFrame;
@@ -141,10 +141,10 @@ public:
void SetWrtShell( SwWrtShell* pShell )
{ pWrtShell = pShell; }
// Feld einfuegen ueber TypeId (TYP_ ...)
sal_Bool InsertFld( const SwInsertFld_Data& rData );
- // Direkt das aktuelle Feld aendern
+ // change the current field directly
void UpdateCurFld(sal_uLong nFormat,
const String& rPar1,
const String& rPar2,
@@ -154,7 +154,7 @@ public:
inline const String& GetCurFldPar2() const;
inline sal_uLong GetCurFldFmt() const;
- // Ein Feld ermitteln
+ // determine a field
SwField* GetCurFld();
void InsertFldType(SwFieldType& rType);
@@ -165,54 +165,54 @@ public:
inline const String& GetMacroName() const { return (sMacroName); }
... etc. - the rest is truncated
More information about the Libreoffice-commits
@@ -141,10 +141,10 @@ public:
void SetWrtShell( SwWrtShell* pShell )
{ pWrtShell = pShell; }
- // Feld einfuegen ueber TypeId (TYP_ ...)
+ // insert field using TypeID (TYP_ ...)
sal_Bool InsertFld( const SwInsertFld_Data& rData );
mailing list